# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Optional, Set
from typing_extensions import Self

class StagePerformanceInput(BaseModel):
    """
    Performance statistics for a retriever stage.
    """ # noqa: E501
    avg_execution_ms: Optional[Union[StrictFloat, StrictInt]] = Field(default=0.0, description="Average execution time in milliseconds")
    execution_count: Optional[StrictInt] = Field(default=0, description="Number of times executed")
    error_count: Optional[StrictInt] = Field(default=0, description="Number of errors encountered")
    last_executed_at: Optional[datetime] = Field(default=None, description="Last time this stage was executed")
    __properties: ClassVar[List[str]] = ["avg_execution_ms", "execution_count", "error_count", "last_executed_at"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of StagePerformanceInput from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of StagePerformanceInput from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "avg_execution_ms": obj.get("avg_execution_ms") if obj.get("avg_execution_ms") is not None else 0.0,
            "execution_count": obj.get("execution_count") if obj.get("execution_count") is not None else 0,
            "error_count": obj.get("error_count") if obj.get("error_count") is not None else 0,
            "last_executed_at": obj.get("last_executed_at")
        })
        return _obj





# coding: utf-8

# flake8: noqa
"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from mixpeek.models.api_key_create_request import APIKeyCreateRequest
from mixpeek.models.api_key_create_response import APIKeyCreateResponse
from mixpeek.models.api_key_model import APIKeyModel
from mixpeek.models.api_key_update_request import APIKeyUpdateRequest
from mixpeek.models.account_tier import AccountTier
from mixpeek.models.add_credits_request import AddCreditsRequest
from mixpeek.models.add_credits_response import AddCreditsResponse
from mixpeek.models.add_objects_to_batch_request import AddObjectsToBatchRequest
from mixpeek.models.add_user_to_organization_request import AddUserToOrganizationRequest
from mixpeek.models.adhoc_execute_request import AdhocExecuteRequest
from mixpeek.models.adhoc_execution_detail import AdhocExecutionDetail
from mixpeek.models.adhoc_execution_summary import AdhocExecutionSummary
from mixpeek.models.agent_config import AgentConfig
from mixpeek.models.agglomerative_params import AgglomerativeParams
from mixpeek.models.aggregation_function import AggregationFunction
from mixpeek.models.aggregation_operation import AggregationOperation
from mixpeek.models.aggregation_result import AggregationResult
from mixpeek.models.alert_application_config_input import AlertApplicationConfigInput
from mixpeek.models.alert_application_config_output import AlertApplicationConfigOutput
from mixpeek.models.alert_execution_list_response import AlertExecutionListResponse
from mixpeek.models.alert_execution_mode import AlertExecutionMode
from mixpeek.models.alert_execution_result import AlertExecutionResult
from mixpeek.models.alert_input_mapping import AlertInputMapping
from mixpeek.models.alert_list_stats import AlertListStats
from mixpeek.models.alert_match_result import AlertMatchResult
from mixpeek.models.alert_notification_config import AlertNotificationConfig
from mixpeek.models.alert_response import AlertResponse
from mixpeek.models.algorithm_params import AlgorithmParams
from mixpeek.models.alignment_metrics import AlignmentMetrics
from mixpeek.models.and_inner import AndInner
from mixpeek.models.and_inner1 import AndInner1
from mixpeek.models.and_inner2 import AndInner2
from mixpeek.models.anthropic_model import AnthropicModel
from mixpeek.models.api_analytics_buckets_models_time_range import ApiAnalyticsBucketsModelsTimeRange
from mixpeek.models.api_analytics_clusters_models_failure_analysis_response import ApiAnalyticsClustersModelsFailureAnalysisResponse
from mixpeek.models.api_analytics_clusters_models_time_range import ApiAnalyticsClustersModelsTimeRange
from mixpeek.models.api_analytics_collections_models_failure_analysis_response import ApiAnalyticsCollectionsModelsFailureAnalysisResponse
from mixpeek.models.api_analytics_collections_models_time_range import ApiAnalyticsCollectionsModelsTimeRange
from mixpeek.models.api_analytics_models_time_range import ApiAnalyticsModelsTimeRange
from mixpeek.models.api_analytics_taxonomies_models_time_range import ApiAnalyticsTaxonomiesModelsTimeRange
from mixpeek.models.api_namespaces_plugins_models_create_plugin_upload_request import ApiNamespacesPluginsModelsCreatePluginUploadRequest
from mixpeek.models.api_namespaces_plugins_models_plugin_delete_response import ApiNamespacesPluginsModelsPluginDeleteResponse
from mixpeek.models.api_namespaces_plugins_models_plugin_detail_response import ApiNamespacesPluginsModelsPluginDetailResponse
from mixpeek.models.api_namespaces_plugins_models_plugin_document import ApiNamespacesPluginsModelsPluginDocument
from mixpeek.models.api_namespaces_plugins_models_plugin_list_response import ApiNamespacesPluginsModelsPluginListResponse
from mixpeek.models.api_namespaces_plugins_models_plugin_manifest_metadata import ApiNamespacesPluginsModelsPluginManifestMetadata
from mixpeek.models.api_namespaces_plugins_models_plugin_presigned_url_response import ApiNamespacesPluginsModelsPluginPresignedURLResponse
from mixpeek.models.api_plugins_models_create_plugin_upload_request import ApiPluginsModelsCreatePluginUploadRequest
from mixpeek.models.api_plugins_models_plugin_delete_response import ApiPluginsModelsPluginDeleteResponse
from mixpeek.models.api_plugins_models_plugin_detail_response import ApiPluginsModelsPluginDetailResponse
from mixpeek.models.api_plugins_models_plugin_document import ApiPluginsModelsPluginDocument
from mixpeek.models.api_plugins_models_plugin_list_response import ApiPluginsModelsPluginListResponse
from mixpeek.models.api_plugins_models_plugin_manifest_metadata import ApiPluginsModelsPluginManifestMetadata
from mixpeek.models.api_plugins_models_plugin_presigned_url_response import ApiPluginsModelsPluginPresignedURLResponse
from mixpeek.models.apply_cluster_enrichment_request import ApplyClusterEnrichmentRequest
from mixpeek.models.apply_result import ApplyResult
from mixpeek.models.apply_taxonomy_request import ApplyTaxonomyRequest
from mixpeek.models.apply_taxonomy_response import ApplyTaxonomyResponse
from mixpeek.models.assignment_metric import AssignmentMetric
from mixpeek.models.assignment_metrics_response import AssignmentMetricsResponse
from mixpeek.models.attribute_based_config import AttributeBasedConfig
from mixpeek.models.audit_action import AuditAction
from mixpeek.models.audit_event_list_response import AuditEventListResponse
from mixpeek.models.audit_event_response import AuditEventResponse
from mixpeek.models.audit_settings import AuditSettings
from mixpeek.models.audit_settings_update_request import AuditSettingsUpdateRequest
from mixpeek.models.auth_config import AuthConfig
from mixpeek.models.auth_type import AuthType
from mixpeek.models.auto_billing_toggle_response import AutoBillingToggleResponse
from mixpeek.models.available_org_model_item import AvailableOrgModelItem
from mixpeek.models.available_org_models_response import AvailableOrgModelsResponse
from mixpeek.models.available_org_plugin_item import AvailableOrgPluginItem
from mixpeek.models.available_org_plugins_response import AvailableOrgPluginsResponse
from mixpeek.models.available_steps_response import AvailableStepsResponse
from mixpeek.models.base_feature_extractor_model_input import BaseFeatureExtractorModelInput
from mixpeek.models.base_feature_extractor_model_output import BaseFeatureExtractorModelOutput
from mixpeek.models.base_rate_limits import BaseRateLimits
from mixpeek.models.base_template_model import BaseTemplateModel
from mixpeek.models.batch_confirm_request import BatchConfirmRequest
from mixpeek.models.batch_confirm_response import BatchConfirmResponse
from mixpeek.models.batch_delete_documents_request import BatchDeleteDocumentsRequest
from mixpeek.models.batch_delete_documents_response import BatchDeleteDocumentsResponse
from mixpeek.models.batch_diagnostics import BatchDiagnostics
from mixpeek.models.batch_document_delete_result import BatchDocumentDeleteResult
from mixpeek.models.batch_document_update import BatchDocumentUpdate
from mixpeek.models.batch_document_update_result import BatchDocumentUpdateResult
from mixpeek.models.batch_error_detail import BatchErrorDetail
from mixpeek.models.batch_model import BatchModel
from mixpeek.models.batch_options import BatchOptions
from mixpeek.models.batch_statistics import BatchStatistics
from mixpeek.models.batch_type import BatchType
from mixpeek.models.batch_update_documents_request import BatchUpdateDocumentsRequest
from mixpeek.models.batch_update_documents_response import BatchUpdateDocumentsResponse
from mixpeek.models.batch_upload_request import BatchUploadRequest
from mixpeek.models.batch_upload_response import BatchUploadResponse
from mixpeek.models.benchmark_comparison import BenchmarkComparison
from mixpeek.models.benchmark_list_response import BenchmarkListResponse
from mixpeek.models.benchmark_response import BenchmarkResponse
from mixpeek.models.benchmark_result import BenchmarkResult
from mixpeek.models.benchmark_status import BenchmarkStatus
from mixpeek.models.blob_details import BlobDetails
from mixpeek.models.blob_mapping_entry import BlobMappingEntry
from mixpeek.models.blob_model import BlobModel
from mixpeek.models.blob_type import BlobType
from mixpeek.models.blob_url_ref import BlobURLRef
from mixpeek.models.bool_index_params import BoolIndexParams
from mixpeek.models.bottleneck_analysis import BottleneckAnalysis
from mixpeek.models.bottleneck_response import BottleneckResponse
from mixpeek.models.bucket_create_request import BucketCreateRequest
from mixpeek.models.bucket_health_response import BucketHealthResponse
from mixpeek.models.bucket_list_stats import BucketListStats
from mixpeek.models.bucket_patch_request import BucketPatchRequest
from mixpeek.models.bucket_response import BucketResponse
from mixpeek.models.bucket_schema_field_input import BucketSchemaFieldInput
from mixpeek.models.bucket_schema_field_output import BucketSchemaFieldOutput
from mixpeek.models.bucket_schema_field_type import BucketSchemaFieldType
from mixpeek.models.bucket_schema_input import BucketSchemaInput
from mixpeek.models.bucket_schema_output import BucketSchemaOutput
from mixpeek.models.bucket_storage_response import BucketStorageResponse
from mixpeek.models.bucket_update_request import BucketUpdateRequest
from mixpeek.models.bucket_usage_response import BucketUsageResponse
from mixpeek.models.budget_limits import BudgetLimits
from mixpeek.models.bulk_update_documents_request import BulkUpdateDocumentsRequest
from mixpeek.models.bulk_update_documents_response import BulkUpdateDocumentsResponse
from mixpeek.models.cors_configuration_info import CORSConfigurationInfo
from mixpeek.models.cors_configuration_response import CORSConfigurationResponse
from mixpeek.models.cache_config import CacheConfig
from mixpeek.models.cache_performance_response import CachePerformanceResponse
from mixpeek.models.cache_statistics import CacheStatistics
from mixpeek.models.cancel_migration_request import CancelMigrationRequest
from mixpeek.models.cancel_migration_response import CancelMigrationResponse
from mixpeek.models.chunk_strategy import ChunkStrategy
from mixpeek.models.citation_config import CitationConfig
from mixpeek.models.clarification_option import ClarificationOption
from mixpeek.models.clone_collection_request import CloneCollectionRequest
from mixpeek.models.clone_collection_response import CloneCollectionResponse
from mixpeek.models.clone_namespace_request import CloneNamespaceRequest
from mixpeek.models.clone_namespace_resources_config import CloneNamespaceResourcesConfig
from mixpeek.models.clone_namespace_response import CloneNamespaceResponse
from mixpeek.models.clone_retriever_request import CloneRetrieverRequest
from mixpeek.models.clone_retriever_response import CloneRetrieverResponse
from mixpeek.models.clone_taxonomy_request import CloneTaxonomyRequest
from mixpeek.models.clone_taxonomy_response import CloneTaxonomyResponse
from mixpeek.models.cloned_resource_summary import ClonedResourceSummary
from mixpeek.models.cluster_application_config import ClusterApplicationConfig
from mixpeek.models.cluster_execution_centroid import ClusterExecutionCentroid
from mixpeek.models.cluster_execution_list_stats import ClusterExecutionListStats
from mixpeek.models.cluster_execution_metric import ClusterExecutionMetric
from mixpeek.models.cluster_execution_metrics import ClusterExecutionMetrics
from mixpeek.models.cluster_execution_result import ClusterExecutionResult
from mixpeek.models.cluster_list_stats import ClusterListStats
from mixpeek.models.cluster_metadata import ClusterMetadata
from mixpeek.models.cluster_model import ClusterModel
from mixpeek.models.cluster_options import ClusterOptions
from mixpeek.models.cluster_stats import ClusterStats
from mixpeek.models.cluster_type import ClusterType
from mixpeek.models.clustering_algorithm import ClusteringAlgorithm
from mixpeek.models.clustering_enrichment_response import ClusteringEnrichmentResponse
from mixpeek.models.collection_detail import CollectionDetail
from mixpeek.models.collection_diagnostic import CollectionDiagnostic
from mixpeek.models.collection_export_request import CollectionExportRequest
from mixpeek.models.collection_export_response import CollectionExportResponse
from mixpeek.models.collection_feature_descriptor import CollectionFeatureDescriptor
from mixpeek.models.collection_list_stats import CollectionListStats
from mixpeek.models.collection_model import CollectionModel
from mixpeek.models.collection_overview_response import CollectionOverviewResponse
from mixpeek.models.collection_response import CollectionResponse
from mixpeek.models.column_source import ColumnSource
from mixpeek.models.components_config import ComponentsConfig
from mixpeek.models.compound_index_pattern import CompoundIndexPattern
from mixpeek.models.compound_index_response import CompoundIndexResponse
from mixpeek.models.compute_tier import ComputeTier
from mixpeek.models.confidence_distribution import ConfidenceDistribution
from mixpeek.models.confidence_response import ConfidenceResponse
from mixpeek.models.config import Config
from mixpeek.models.config1 import Config1
from mixpeek.models.config2 import Config2
from mixpeek.models.configs import Configs
from mixpeek.models.configure_cors_request import ConfigureCORSRequest
from mixpeek.models.confirm_model_upload_request import ConfirmModelUploadRequest
from mixpeek.models.confirm_model_upload_response import ConfirmModelUploadResponse
from mixpeek.models.confirm_payment_method_request import ConfirmPaymentMethodRequest
from mixpeek.models.confirm_payment_method_response import ConfirmPaymentMethodResponse
from mixpeek.models.confirm_plugin_upload_request import ConfirmPluginUploadRequest
from mixpeek.models.confirm_plugin_upload_response import ConfirmPluginUploadResponse
from mixpeek.models.confirm_upload_request import ConfirmUploadRequest
from mixpeek.models.confirm_upload_response import ConfirmUploadResponse
from mixpeek.models.confirmation_request import ConfirmationRequest
from mixpeek.models.constant_source import ConstantSource
from mixpeek.models.content_input import ContentInput
from mixpeek.models.content_input1 import ContentInput1
from mixpeek.models.content_query_input import ContentQueryInput
from mixpeek.models.content_query_input1 import ContentQueryInput1
from mixpeek.models.cost_breakdown import CostBreakdown
from mixpeek.models.cost_rate import CostRate
from mixpeek.models.cost_unit import CostUnit
from mixpeek.models.costs_info import CostsInfo
from mixpeek.models.course_content_extractor_params import CourseContentExtractorParams
from mixpeek.models.covariate_config import CovariateConfig
from mixpeek.models.covariate_type import CovariateType
from mixpeek.models.crawl_mode import CrawlMode
from mixpeek.models.create_alert_request import CreateAlertRequest
from mixpeek.models.create_batch_request import CreateBatchRequest
from mixpeek.models.create_benchmark_request import CreateBenchmarkRequest
from mixpeek.models.create_blob_request import CreateBlobRequest
from mixpeek.models.create_cluster_request import CreateClusterRequest
from mixpeek.models.create_collection_request import CreateCollectionRequest
from mixpeek.models.create_dataset_request import CreateDatasetRequest
from mixpeek.models.create_migration_request import CreateMigrationRequest
from mixpeek.models.create_migration_response import CreateMigrationResponse
from mixpeek.models.create_model_upload_request import CreateModelUploadRequest
from mixpeek.models.create_namespace_request import CreateNamespaceRequest
from mixpeek.models.create_object_request import CreateObjectRequest
from mixpeek.models.create_objects_batch_request import CreateObjectsBatchRequest
from mixpeek.models.create_objects_batch_response import CreateObjectsBatchResponse
from mixpeek.models.create_organization_request import CreateOrganizationRequest
from mixpeek.models.create_retriever_request import CreateRetrieverRequest
from mixpeek.models.create_retriever_response import CreateRetrieverResponse
from mixpeek.models.create_secret_request import CreateSecretRequest
from mixpeek.models.create_session_request import CreateSessionRequest
from mixpeek.models.create_session_response import CreateSessionResponse
from mixpeek.models.create_taxonomy_request import CreateTaxonomyRequest
from mixpeek.models.create_template_from_resource_request import CreateTemplateFromResourceRequest
from mixpeek.models.create_template_from_resource_response import CreateTemplateFromResourceResponse
from mixpeek.models.create_upload_request import CreateUploadRequest
from mixpeek.models.creator_info import CreatorInfo
from mixpeek.models.credentials import Credentials
from mixpeek.models.credentials1 import Credentials1
from mixpeek.models.credentials2 import Credentials2
from mixpeek.models.credentials3 import Credentials3
from mixpeek.models.credit_balance_response import CreditBalanceResponse
from mixpeek.models.current_usage_response import CurrentUsageResponse
from mixpeek.models.cursor_pagination_params import CursorPaginationParams
from mixpeek.models.custom_cta import CustomCTA
from mixpeek.models.custom_model_document import CustomModelDocument
from mixpeek.models.custom_plugin_params import CustomPluginParams
from mixpeek.models.dbscan_params import DBSCANParams
from mixpeek.models.data import Data
from mixpeek.models.dataset_list_response import DatasetListResponse
from mixpeek.models.date_part_unit import DatePartUnit
from mixpeek.models.date_trunc_unit import DateTruncUnit
from mixpeek.models.datetime_index_params import DatetimeIndexParams
from mixpeek.models.dbscan_parameters import DbscanParameters
from mixpeek.models.dependency_graph import DependencyGraph
from mixpeek.models.dependency_node import DependencyNode
from mixpeek.models.describe_collection_features_response import DescribeCollectionFeaturesResponse
from mixpeek.models.detect_intent_request import DetectIntentRequest
from mixpeek.models.diff_item import DiffItem
from mixpeek.models.diff_result import DiffResult
from mixpeek.models.disable_org_model_response import DisableOrgModelResponse
from mixpeek.models.disable_org_plugin_response import DisableOrgPluginResponse
from mixpeek.models.display_config_input import DisplayConfigInput
from mixpeek.models.display_config_output import DisplayConfigOutput
from mixpeek.models.diversity_feature_config import DiversityFeatureConfig
from mixpeek.models.document_aggregation_request import DocumentAggregationRequest
from mixpeek.models.document_aggregation_response import DocumentAggregationResponse
from mixpeek.models.document_create_request import DocumentCreateRequest
from mixpeek.models.document_graph_extractor_params import DocumentGraphExtractorParams
from mixpeek.models.document_group import DocumentGroup
from mixpeek.models.document_id_strategy import DocumentIdStrategy
from mixpeek.models.document_list_stats import DocumentListStats
from mixpeek.models.document_query_input import DocumentQueryInput
from mixpeek.models.document_query_input1 import DocumentQueryInput1
from mixpeek.models.document_reference import DocumentReference
from mixpeek.models.document_reference1 import DocumentReference1
from mixpeek.models.document_response import DocumentResponse
from mixpeek.models.drive_property_source import DrivePropertySource
from mixpeek.models.duration_stats import DurationStats
from mixpeek.models.dynamic_value import DynamicValue
from mixpeek.models.dynamic_value1 import DynamicValue1
from mixpeek.models.dynamic_value2 import DynamicValue2
from mixpeek.models.dynamic_value3 import DynamicValue3
from mixpeek.models.dynamic_value4 import DynamicValue4
from mixpeek.models.dynamic_value5 import DynamicValue5
from mixpeek.models.dynamic_value6 import DynamicValue6
from mixpeek.models.email_config import EmailConfig
from mixpeek.models.enable_org_model_request import EnableOrgModelRequest
from mixpeek.models.enable_org_model_response import EnableOrgModelResponse
from mixpeek.models.enable_org_plugin_request import EnableOrgPluginRequest
from mixpeek.models.enable_org_plugin_response import EnableOrgPluginResponse
from mixpeek.models.engine_performance_response import EnginePerformanceResponse
from mixpeek.models.engine_stage_breakdown_response import EngineStageBreakdownResponse
from mixpeek.models.enrichment_field import EnrichmentField
from mixpeek.models.enrichment_field_mapping import EnrichmentFieldMapping
from mixpeek.models.enrichment_history_response import EnrichmentHistoryResponse
from mixpeek.models.enrichment_merge_mode import EnrichmentMergeMode
from mixpeek.models.enrichment_metric import EnrichmentMetric
from mixpeek.models.error_breakdown import ErrorBreakdown
from mixpeek.models.error_category import ErrorCategory
from mixpeek.models.error_detail import ErrorDetail
from mixpeek.models.error_handling import ErrorHandling
from mixpeek.models.error_handling1 import ErrorHandling1
from mixpeek.models.error_handling2 import ErrorHandling2
from mixpeek.models.error_handling3 import ErrorHandling3
from mixpeek.models.error_metrics import ErrorMetrics
from mixpeek.models.error_response import ErrorResponse
from mixpeek.models.evaluation_config import EvaluationConfig
from mixpeek.models.evaluation_dataset import EvaluationDataset
from mixpeek.models.evaluation_list_response import EvaluationListResponse
from mixpeek.models.evaluation_record import EvaluationRecord
from mixpeek.models.evaluation_status import EvaluationStatus
from mixpeek.models.execute_retriever_request import ExecuteRetrieverRequest
from mixpeek.models.execute_taxonomy_request import ExecuteTaxonomyRequest
from mixpeek.models.execution_detail import ExecutionDetail
from mixpeek.models.execution_history_response import ExecutionHistoryResponse
from mixpeek.models.explain_retriever_request import ExplainRetrieverRequest
from mixpeek.models.explain_retriever_response import ExplainRetrieverResponse
from mixpeek.models.explain_stage_plan import ExplainStagePlan
from mixpeek.models.export_format import ExportFormat
from mixpeek.models.external_link import ExternalLink
from mixpeek.models.extractor_breakdown_response import ExtractorBreakdownResponse
from mixpeek.models.extractor_job_info import ExtractorJobInfo
from mixpeek.models.extractor_metrics import ExtractorMetrics
from mixpeek.models.extractor_performance import ExtractorPerformance
from mixpeek.models.extractor_performance_response import ExtractorPerformanceResponse
from mixpeek.models.extractor_source import ExtractorSource
from mixpeek.models.face_identity_extractor_params import FaceIdentityExtractorParams
from mixpeek.models.facet_field_config import FacetFieldConfig
from mixpeek.models.failed_object_error import FailedObjectError
from mixpeek.models.failure_metric import FailureMetric
from mixpeek.models.feature_address import FeatureAddress
from mixpeek.models.feature_extractor_response_model import FeatureExtractorResponseModel
from mixpeek.models.feature_model import FeatureModel
from mixpeek.models.feature_search_config import FeatureSearchConfig
from mixpeek.models.feature_search_group_by import FeatureSearchGroupBy
from mixpeek.models.field_config import FieldConfig
from mixpeek.models.field_format_options import FieldFormatOptions
from mixpeek.models.field_format_type import FieldFormatType
from mixpeek.models.field_mapping_entry import FieldMappingEntry
from mixpeek.models.field_passthrough import FieldPassthrough
from mixpeek.models.field_performance_metrics import FieldPerformanceMetrics
from mixpeek.models.field_performance_response import FieldPerformanceResponse
from mixpeek.models.field_query_metrics import FieldQueryMetrics
from mixpeek.models.field_schema import FieldSchema
from mixpeek.models.field_usage_response import FieldUsageResponse
from mixpeek.models.field_usage_stat import FieldUsageStat
from mixpeek.models.file_filters import FileFilters
from mixpeek.models.file_source import FileSource
from mixpeek.models.filename_regex_source import FilenameRegexSource
from mixpeek.models.filter_condition import FilterCondition
from mixpeek.models.filter_condition1 import FilterCondition1
from mixpeek.models.filter_condition2 import FilterCondition2
from mixpeek.models.filter_condition3 import FilterCondition3
from mixpeek.models.filter_condition4 import FilterCondition4
from mixpeek.models.filter_condition5 import FilterCondition5
from mixpeek.models.filter_condition6 import FilterCondition6
from mixpeek.models.filter_operator import FilterOperator
from mixpeek.models.filter_operator1 import FilterOperator1
from mixpeek.models.filter_operator2 import FilterOperator2
from mixpeek.models.filter_operator3 import FilterOperator3
from mixpeek.models.filter_operator4 import FilterOperator4
from mixpeek.models.filter_operator5 import FilterOperator5
from mixpeek.models.filter_operator6 import FilterOperator6
from mixpeek.models.flat_taxonomy_config_input import FlatTaxonomyConfigInput
from mixpeek.models.flat_taxonomy_config_output import FlatTaxonomyConfigOutput
from mixpeek.models.float_index_params import FloatIndexParams
from mixpeek.models.folder_item import FolderItem
from mixpeek.models.folder_path_source import FolderPathSource
from mixpeek.models.fusion_strategy import FusionStrategy
from mixpeek.models.gaussian_mixture_params import GaussianMixtureParams
from mixpeek.models.generation_config import GenerationConfig
from mixpeek.models.generic_delete_response import GenericDeleteResponse
from mixpeek.models.generic_success_response import GenericSuccessResponse
from mixpeek.models.geo_index_params import GeoIndexParams
from mixpeek.models.get_history_response import GetHistoryResponse
from mixpeek.models.get_migration_response import GetMigrationResponse
from mixpeek.models.get_payment_method_response import GetPaymentMethodResponse
from mixpeek.models.get_session_response import GetSessionResponse
from mixpeek.models.google_drive_config import GoogleDriveConfig
from mixpeek.models.google_drive_o_auth_credentials import GoogleDriveOAuthCredentials
from mixpeek.models.google_drive_service_account_credentials import GoogleDriveServiceAccountCredentials
from mixpeek.models.google_model import GoogleModel
from mixpeek.models.ground_truth_query import GroundTruthQuery
from mixpeek.models.group_by_field import GroupByField
from mixpeek.models.group_by_field_config import GroupByFieldConfig
from mixpeek.models.growth_metric import GrowthMetric
from mixpeek.models.growth_metrics_response import GrowthMetricsResponse
from mixpeek.models.hdbscan_params import HDBSCANParams
from mixpeek.models.http_validation_error import HTTPValidationError
from mixpeek.models.having_condition import HavingCondition
from mixpeek.models.hdbscan_parameters import HdbscanParameters
from mixpeek.models.health_check import HealthCheck
from mixpeek.models.health_check_response import HealthCheckResponse
from mixpeek.models.health_service_errors import HealthServiceErrors
from mixpeek.models.health_service_status import HealthServiceStatus
from mixpeek.models.health_status_input import HealthStatusInput
from mixpeek.models.health_status_output import HealthStatusOutput
from mixpeek.models.hierarchical_enrichment_style import HierarchicalEnrichmentStyle
from mixpeek.models.hierarchical_node_input import HierarchicalNodeInput
from mixpeek.models.hierarchical_node_output import HierarchicalNodeOutput
from mixpeek.models.hierarchical_taxonomy_config_input import HierarchicalTaxonomyConfigInput
from mixpeek.models.hierarchical_taxonomy_config_output import HierarchicalTaxonomyConfigOutput
from mixpeek.models.hierarchy_inference_strategy import HierarchyInferenceStrategy
from mixpeek.models.image_extractor_params import ImageExtractorParams
from mixpeek.models.index import Index
from mixpeek.models.index_recommendation import IndexRecommendation
from mixpeek.models.index_recommendations_response import IndexRecommendationsResponse
from mixpeek.models.index_suggestion import IndexSuggestion
from mixpeek.models.index_suggestions_response import IndexSuggestionsResponse
from mixpeek.models.input_mapping import InputMapping
from mixpeek.models.input_mapping_source import InputMappingSource
from mixpeek.models.input_mappings import InputMappings
from mixpeek.models.input_rendering_config_input import InputRenderingConfigInput
from mixpeek.models.input_rendering_config_output import InputRenderingConfigOutput
from mixpeek.models.input_source_type import InputSourceType
from mixpeek.models.instantiate_bucket_template_request import InstantiateBucketTemplateRequest
from mixpeek.models.instantiate_cluster_template_request import InstantiateClusterTemplateRequest
from mixpeek.models.instantiate_collection_template_request import InstantiateCollectionTemplateRequest
from mixpeek.models.instantiate_retriever_template_request import InstantiateRetrieverTemplateRequest
from mixpeek.models.instantiate_scaffold_request import InstantiateScaffoldRequest
from mixpeek.models.instantiate_taxonomy_template_request import InstantiateTaxonomyTemplateRequest
from mixpeek.models.instantiate_template_request import InstantiateTemplateRequest
from mixpeek.models.instantiated_bucket_template_response import InstantiatedBucketTemplateResponse
from mixpeek.models.instantiated_cluster_template_response import InstantiatedClusterTemplateResponse
from mixpeek.models.instantiated_collection_template_response import InstantiatedCollectionTemplateResponse
from mixpeek.models.instantiated_retriever_template_response import InstantiatedRetrieverTemplateResponse
from mixpeek.models.instantiated_scaffold_response import InstantiatedScaffoldResponse
from mixpeek.models.instantiated_taxonomy_template_response import InstantiatedTaxonomyTemplateResponse
from mixpeek.models.instantiated_template_response import InstantiatedTemplateResponse
from mixpeek.models.integer_index_params import IntegerIndexParams
from mixpeek.models.intent_classification import IntentClassification
from mixpeek.models.interaction_response import InteractionResponse
from mixpeek.models.interaction_tuning_recommendation import InteractionTuningRecommendation
from mixpeek.models.interaction_tuning_response import InteractionTuningResponse
from mixpeek.models.interaction_type import InteractionType
from mixpeek.models.interaction_weights import InteractionWeights
from mixpeek.models.internal_lineage_model import InternalLineageModel
from mixpeek.models.internal_payload_model import InternalPayloadModel
from mixpeek.models.internal_processing_model import InternalProcessingModel
from mixpeek.models.invoice_info import InvoiceInfo
from mixpeek.models.invoice_list_response import InvoiceListResponse
from mixpeek.models.join_mode import JoinMode
from mixpeek.models.join_response import JoinResponse
from mixpeek.models.join_stats import JoinStats
from mixpeek.models.k_means_params import KMeansParams
from mixpeek.models.key_status import KeyStatus
from mixpeek.models.keyset_pagination_params import KeysetPaginationParams
from mixpeek.models.keyword_index_params import KeywordIndexParams
from mixpeek.models.kmeans_parameters import KmeansParameters
from mixpeek.models.llm_labeling_input import LLMLabelingInput
from mixpeek.models.llm_labeling_input_input import LLMLabelingInputInput
from mixpeek.models.llm_labeling_input_output import LLMLabelingInputOutput
from mixpeek.models.llm_labeling_output import LLMLabelingOutput
from mixpeek.models.llm_provider import LLMProvider
from mixpeek.models.llm_provider1 import LLMProvider1
from mixpeek.models.llm_provider2 import LLMProvider2
from mixpeek.models.label_distribution_response import LabelDistributionResponse
from mixpeek.models.label_metric import LabelMetric
from mixpeek.models.latency_metric import LatencyMetric
from mixpeek.models.latency_metrics import LatencyMetrics
from mixpeek.models.latency_response import LatencyResponse
from mixpeek.models.layout_config import LayoutConfig
from mixpeek.models.learned_fusion_config import LearnedFusionConfig
from mixpeek.models.learning_algorithm import LearningAlgorithm
from mixpeek.models.lineage_step import LineageStep
from mixpeek.models.list_adhoc_executions_request import ListAdhocExecutionsRequest
from mixpeek.models.list_adhoc_executions_response import ListAdhocExecutionsResponse
from mixpeek.models.list_alerts_request import ListAlertsRequest
from mixpeek.models.list_alerts_response import ListAlertsResponse
from mixpeek.models.list_batches_request import ListBatchesRequest
from mixpeek.models.list_batches_response import ListBatchesResponse
from mixpeek.models.list_buckets_request import ListBucketsRequest
from mixpeek.models.list_buckets_response import ListBucketsResponse
from mixpeek.models.list_cluster_executions_request import ListClusterExecutionsRequest
from mixpeek.models.list_cluster_executions_response import ListClusterExecutionsResponse
from mixpeek.models.list_clusters_request import ListClustersRequest
from mixpeek.models.list_clusters_response import ListClustersResponse
from mixpeek.models.list_collections_request import ListCollectionsRequest
from mixpeek.models.list_collections_response import ListCollectionsResponse
from mixpeek.models.list_documents_request import ListDocumentsRequest
from mixpeek.models.list_documents_response import ListDocumentsResponse
from mixpeek.models.list_executions_request import ListExecutionsRequest
from mixpeek.models.list_executions_response import ListExecutionsResponse
from mixpeek.models.list_folders_response import ListFoldersResponse
from mixpeek.models.list_interactions_request import ListInteractionsRequest
from mixpeek.models.list_interactions_response import ListInteractionsResponse
from mixpeek.models.list_migrations_request import ListMigrationsRequest
from mixpeek.models.list_migrations_response import ListMigrationsResponse
from mixpeek.models.list_namespaces_request import ListNamespacesRequest
from mixpeek.models.list_namespaces_response import ListNamespacesResponse
from mixpeek.models.list_notifications_request import ListNotificationsRequest
from mixpeek.models.list_notifications_response import ListNotificationsResponse
from mixpeek.models.list_objects_request import ListObjectsRequest
from mixpeek.models.list_objects_response import ListObjectsResponse
from mixpeek.models.list_public_retrievers_response import ListPublicRetrieversResponse
from mixpeek.models.list_retrievers_request import ListRetrieversRequest
from mixpeek.models.list_retrievers_response import ListRetrieversResponse
from mixpeek.models.list_sessions_request import ListSessionsRequest
from mixpeek.models.list_sessions_response import ListSessionsResponse
from mixpeek.models.list_storage_connections_request import ListStorageConnectionsRequest
from mixpeek.models.list_sync_configurations_request import ListSyncConfigurationsRequest
from mixpeek.models.list_tasks_request import ListTasksRequest
from mixpeek.models.list_tasks_response import ListTasksResponse
from mixpeek.models.list_taxonomies_request import ListTaxonomiesRequest
from mixpeek.models.list_taxonomies_response import ListTaxonomiesResponse
from mixpeek.models.list_templates_request import ListTemplatesRequest
from mixpeek.models.list_templates_response import ListTemplatesResponse
from mixpeek.models.list_tools_response import ListToolsResponse
from mixpeek.models.list_uploads_request import ListUploadsRequest
from mixpeek.models.list_uploads_response import ListUploadsResponse
from mixpeek.models.list_webhooks_request import ListWebhooksRequest
from mixpeek.models.list_webhooks_response import ListWebhooksResponse
from mixpeek.models.logical_operator import LogicalOperator
from mixpeek.models.logical_operator1 import LogicalOperator1
from mixpeek.models.logical_operator2 import LogicalOperator2
from mixpeek.models.logical_operator3 import LogicalOperator3
from mixpeek.models.logical_operator4 import LogicalOperator4
from mixpeek.models.logical_operator5 import LogicalOperator5
from mixpeek.models.logical_operator6 import LogicalOperator6
from mixpeek.models.logical_operator_input import LogicalOperatorInput
from mixpeek.models.logical_operator_output import LogicalOperatorOutput
from mixpeek.models.mappings_value import MappingsValue
from mixpeek.models.mark_as_read_request import MarkAsReadRequest
from mixpeek.models.markdown_content import MarkdownContent
from mixpeek.models.mean_shift_params import MeanShiftParams
from mixpeek.models.message_history_item import MessageHistoryItem
from mixpeek.models.migration_config import MigrationConfig
from mixpeek.models.migration_progress import MigrationProgress
from mixpeek.models.migration_stage import MigrationStage
from mixpeek.models.migration_status import MigrationStatus
from mixpeek.models.migration_type import MigrationType
from mixpeek.models.model_delete_response import ModelDeleteResponse
from mixpeek.models.model_deploy_response import ModelDeployResponse
from mixpeek.models.model_deployment_info import ModelDeploymentInfo
from mixpeek.models.model_detail_response import ModelDetailResponse
from mixpeek.models.model_list_item import ModelListItem
from mixpeek.models.model_list_response import ModelListResponse
from mixpeek.models.model_name import ModelName
from mixpeek.models.model_presigned_url_response import ModelPresignedURLResponse
from mixpeek.models.model_resource_requirements import ModelResourceRequirements
from mixpeek.models.model_upload_response import ModelUploadResponse
from mixpeek.models.most_queried_fields_response import MostQueriedFieldsResponse
from mixpeek.models.multi_vector_index import MultiVectorIndex
from mixpeek.models.multimodal_extractor_params import MultimodalExtractorParams
from mixpeek.models.namespace_infrastructure import NamespaceInfrastructure
from mixpeek.models.namespace_list_stats import NamespaceListStats
from mixpeek.models.namespace_model import NamespaceModel
from mixpeek.models.namespace_operation import NamespaceOperation
from mixpeek.models.namespace_summary_response import NamespaceSummaryResponse
from mixpeek.models.notification import Notification
from mixpeek.models.notification_channel import NotificationChannel
from mixpeek.models.notification_channel_config import NotificationChannelConfig
from mixpeek.models.notification_content_type import NotificationContentType
from mixpeek.models.notification_priority import NotificationPriority
from mixpeek.models.notification_type import NotificationType
from mixpeek.models.optics_params import OPTICSParams
from mixpeek.models.object_aggregation_request import ObjectAggregationRequest
from mixpeek.models.object_aggregation_response import ObjectAggregationResponse
from mixpeek.models.object_list_stats import ObjectListStats
from mixpeek.models.object_response import ObjectResponse
from mixpeek.models.offset_pagination_params import OffsetPaginationParams
from mixpeek.models.on_empty_behavior import OnEmptyBehavior
from mixpeek.models.on_empty_behavior1 import OnEmptyBehavior1
from mixpeek.models.on_no_results import OnNoResults
from mixpeek.models.open_ai_model import OpenAIModel
from mixpeek.models.org_model_delete_response import OrgModelDeleteResponse
from mixpeek.models.org_model_deployment_info import OrgModelDeploymentInfo
from mixpeek.models.org_model_detail_response import OrgModelDetailResponse
from mixpeek.models.org_model_document import OrgModelDocument
from mixpeek.models.org_model_list_item import OrgModelListItem
from mixpeek.models.org_model_list_response import OrgModelListResponse
from mixpeek.models.organization_admin_update_request import OrganizationAdminUpdateRequest
from mixpeek.models.organization_infrastructure import OrganizationInfrastructure
from mixpeek.models.organization_model import OrganizationModel
from mixpeek.models.organization_model_response import OrganizationModelResponse
from mixpeek.models.organization_publish_stats_response import OrganizationPublishStatsResponse
from mixpeek.models.organization_update_request import OrganizationUpdateRequest
from mixpeek.models.pagination import Pagination
from mixpeek.models.pagination_metadata import PaginationMetadata
from mixpeek.models.pagination_method import PaginationMethod
from mixpeek.models.pagination_response import PaginationResponse
from mixpeek.models.parameters import Parameters
from mixpeek.models.patch_alert_request import PatchAlertRequest
from mixpeek.models.patch_batch_request import PatchBatchRequest
from mixpeek.models.patch_cluster_request import PatchClusterRequest
from mixpeek.models.patch_namespace_request import PatchNamespaceRequest
from mixpeek.models.patch_object_request import PatchObjectRequest
from mixpeek.models.patch_retriever_request import PatchRetrieverRequest
from mixpeek.models.patch_retriever_response import PatchRetrieverResponse
from mixpeek.models.patch_session_request import PatchSessionRequest
from mixpeek.models.patch_session_response import PatchSessionResponse
from mixpeek.models.patch_taxonomy_request import PatchTaxonomyRequest
from mixpeek.models.path_analysis_request import PathAnalysisRequest
from mixpeek.models.path_analysis_response import PathAnalysisResponse
from mixpeek.models.payload import Payload
from mixpeek.models.payload_index_config_input import PayloadIndexConfigInput
from mixpeek.models.payload_index_config_output import PayloadIndexConfigOutput
from mixpeek.models.payload_schema_type import PayloadSchemaType
from mixpeek.models.payment_method_info import PaymentMethodInfo
from mixpeek.models.performance_insight import PerformanceInsight
from mixpeek.models.performance_metric import PerformanceMetric
from mixpeek.models.performance_summary import PerformanceSummary
from mixpeek.models.permission import Permission
from mixpeek.models.pipeline_comparison import PipelineComparison
from mixpeek.models.plugin_deployment_info import PluginDeploymentInfo
from mixpeek.models.plugin_list_item import PluginListItem
from mixpeek.models.plugin_status_response import PluginStatusResponse
from mixpeek.models.plugin_upload_response import PluginUploadResponse
from mixpeek.models.post_processing_phase import PostProcessingPhase
from mixpeek.models.postgre_sql_config import PostgreSQLConfig
from mixpeek.models.postgre_sql_credentials import PostgreSQLCredentials
from mixpeek.models.predictor_lift import PredictorLift
from mixpeek.models.provider_config import ProviderConfig
from mixpeek.models.public_interaction_batch_request import PublicInteractionBatchRequest
from mixpeek.models.public_interaction_request import PublicInteractionRequest
from mixpeek.models.public_name_availability_response import PublicNameAvailabilityResponse
from mixpeek.models.public_retriever_config_response import PublicRetrieverConfigResponse
from mixpeek.models.public_retriever_list_item import PublicRetrieverListItem
from mixpeek.models.public_retriever_list_stats import PublicRetrieverListStats
from mixpeek.models.public_retriever_template_response import PublicRetrieverTemplateResponse
from mixpeek.models.publish_retriever_request import PublishRetrieverRequest
from mixpeek.models.publish_retriever_response import PublishRetrieverResponse
from mixpeek.models.published_retriever_response import PublishedRetrieverResponse
from mixpeek.models.query import Query
from mixpeek.models.range_bucket import RangeBucket
from mixpeek.models.range_bucket_boundaries_inner import RangeBucketBoundariesInner
from mixpeek.models.rate_limit_config import RateLimitConfig
from mixpeek.models.rate_limit_tier import RateLimitTier
from mixpeek.models.raw_inference_request import RawInferenceRequest
from mixpeek.models.raw_inference_response import RawInferenceResponse
from mixpeek.models.reminder_preferences import ReminderPreferences
from mixpeek.models.reminder_preferences_response import ReminderPreferencesResponse
from mixpeek.models.render_strategy import RenderStrategy
from mixpeek.models.resource_filter import ResourceFilter
from mixpeek.models.resource_progress import ResourceProgress
from mixpeek.models.resource_result import ResourceResult
from mixpeek.models.resource_result_status import ResourceResultStatus
from mixpeek.models.resource_scope_input import ResourceScopeInput
from mixpeek.models.resource_scope_output import ResourceScopeOutput
from mixpeek.models.resource_type_input import ResourceTypeInput
from mixpeek.models.response_shape import ResponseShape
from mixpeek.models.response_shape1 import ResponseShape1
from mixpeek.models.response_shape2 import ResponseShape2
from mixpeek.models.response_shape3 import ResponseShape3
from mixpeek.models.response_sync_collection_schema_v1_collections_collection_id_sync_schema_post import ResponseSyncCollectionSchemaV1CollectionsCollectionIdSyncSchemaPost
from mixpeek.models.result_card_properties import ResultCardProperties
from mixpeek.models.result_handling import ResultHandling
from mixpeek.models.retriever_config import RetrieverConfig
from mixpeek.models.retriever_execution_request import RetrieverExecutionRequest
from mixpeek.models.retriever_execution_statistics import RetrieverExecutionStatistics
from mixpeek.models.retriever_execution_summary import RetrieverExecutionSummary
from mixpeek.models.retriever_input_schema_field_input import RetrieverInputSchemaFieldInput
from mixpeek.models.retriever_input_schema_field_output import RetrieverInputSchemaFieldOutput
from mixpeek.models.retriever_input_schema_field_type import RetrieverInputSchemaFieldType
from mixpeek.models.retriever_metadata import RetrieverMetadata
from mixpeek.models.retriever_model_input import RetrieverModelInput
from mixpeek.models.retriever_model_output import RetrieverModelOutput
from mixpeek.models.retriever_options import RetrieverOptions
from mixpeek.models.retriever_performance_response import RetrieverPerformanceResponse
from mixpeek.models.retriever_schema import RetrieverSchema
from mixpeek.models.retriever_signal import RetrieverSignal
from mixpeek.models.retriever_stage_definition import RetrieverStageDefinition
from mixpeek.models.retriever_status import RetrieverStatus
from mixpeek.models.retry_batch_request import RetryBatchRequest
from mixpeek.models.revision_history_entry import RevisionHistoryEntry
from mixpeek.models.s3_access_key_credentials import S3AccessKeyCredentials
from mixpeek.models.s3_config import S3Config
from mixpeek.models.s3_metadata_source import S3MetadataSource
from mixpeek.models.s3_role_credentials import S3RoleCredentials
from mixpeek.models.s3_tag_source import S3TagSource
from mixpeek.models.seo_config import SEOConfig
from mixpeek.models.schema_mapping_input import SchemaMappingInput
from mixpeek.models.schema_mapping_output import SchemaMappingOutput
from mixpeek.models.schema_sync_request import SchemaSyncRequest
from mixpeek.models.schema_sync_response import SchemaSyncResponse
from mixpeek.models.schema_sync_skipped_response import SchemaSyncSkippedResponse
from mixpeek.models.scroll_pagination_params import ScrollPaginationParams
from mixpeek.models.search_interaction import SearchInteraction
from mixpeek.models.search_request import SearchRequest
from mixpeek.models.search_response import SearchResponse
from mixpeek.models.search_result_item import SearchResultItem
from mixpeek.models.secret_response import SecretResponse
from mixpeek.models.secrets_list_response import SecretsListResponse
from mixpeek.models.send_message_request import SendMessageRequest
from mixpeek.models.sentiment_classifier_params import SentimentClassifierParams
from mixpeek.models.session_filter_input import SessionFilterInput
from mixpeek.models.session_filter_output import SessionFilterOutput
from mixpeek.models.session_quotas import SessionQuotas
from mixpeek.models.session_stats import SessionStats
from mixpeek.models.session_status import SessionStatus
from mixpeek.models.setup_payment_method_response import SetupPaymentMethodResponse
from mixpeek.models.share_point_client_credentials import SharePointClientCredentials
from mixpeek.models.share_point_config import SharePointConfig
from mixpeek.models.share_point_delegated_credentials import SharePointDelegatedCredentials
from mixpeek.models.shared_clusters_triggers_models_create_trigger_request import SharedClustersTriggersModelsCreateTriggerRequest
from mixpeek.models.shared_clusters_triggers_models_list_triggers_request import SharedClustersTriggersModelsListTriggersRequest
from mixpeek.models.shared_clusters_triggers_models_list_triggers_response import SharedClustersTriggersModelsListTriggersResponse
from mixpeek.models.shared_clusters_triggers_models_trigger_history_response import SharedClustersTriggersModelsTriggerHistoryResponse
from mixpeek.models.shared_clusters_triggers_models_trigger_model import SharedClustersTriggersModelsTriggerModel
from mixpeek.models.shared_clusters_triggers_models_trigger_status import SharedClustersTriggersModelsTriggerStatus
from mixpeek.models.shared_clusters_triggers_models_trigger_type import SharedClustersTriggersModelsTriggerType
from mixpeek.models.shared_clusters_triggers_models_update_trigger_request import SharedClustersTriggersModelsUpdateTriggerRequest
from mixpeek.models.shared_collection_features_extractors_models_feature_extractor_config_input import SharedCollectionFeaturesExtractorsModelsFeatureExtractorConfigInput
from mixpeek.models.shared_collection_features_extractors_models_feature_extractor_config_output import SharedCollectionFeaturesExtractorsModelsFeatureExtractorConfigOutput
from mixpeek.models.shared_namespaces_migrations_models_feature_extractor_config import SharedNamespacesMigrationsModelsFeatureExtractorConfig
from mixpeek.models.shared_namespaces_migrations_models_resource_type import SharedNamespacesMigrationsModelsResourceType
from mixpeek.models.shared_organizations_enums_resource_type import SharedOrganizationsEnumsResourceType
from mixpeek.models.shared_retrievers_benchmarks_models_time_range import SharedRetrieversBenchmarksModelsTimeRange
from mixpeek.models.shared_triggers_models_create_trigger_request import SharedTriggersModelsCreateTriggerRequest
from mixpeek.models.shared_triggers_models_list_triggers_request import SharedTriggersModelsListTriggersRequest
from mixpeek.models.shared_triggers_models_list_triggers_response import SharedTriggersModelsListTriggersResponse
from mixpeek.models.shared_triggers_models_trigger_history_response import SharedTriggersModelsTriggerHistoryResponse
from mixpeek.models.shared_triggers_models_trigger_model import SharedTriggersModelsTriggerModel
from mixpeek.models.shared_triggers_models_trigger_status import SharedTriggersModelsTriggerStatus
from mixpeek.models.shared_triggers_models_trigger_type import SharedTriggersModelsTriggerType
from mixpeek.models.shared_triggers_models_update_trigger_request import SharedTriggersModelsUpdateTriggerRequest
from mixpeek.models.single_lineage_entry import SingleLineageEntry
from mixpeek.models.slack_config import SlackConfig
from mixpeek.models.slow_operation import SlowOperation
from mixpeek.models.slow_operations_response import SlowOperationsResponse
from mixpeek.models.slow_queries_response import SlowQueriesResponse
from mixpeek.models.slow_query_details import SlowQueryDetails
from mixpeek.models.snowflake_config import SnowflakeConfig
from mixpeek.models.snowflake_key_pair_credentials import SnowflakeKeyPairCredentials
from mixpeek.models.snowflake_username_password_credentials import SnowflakeUsernamePasswordCredentials
from mixpeek.models.sort_direction import SortDirection
from mixpeek.models.sort_direction1 import SortDirection1
from mixpeek.models.sort_option import SortOption
from mixpeek.models.source import Source
from mixpeek.models.source1 import Source1
from mixpeek.models.source_collection_input import SourceCollectionInput
from mixpeek.models.source_collection_output import SourceCollectionOutput
from mixpeek.models.source_config_input import SourceConfigInput
from mixpeek.models.source_config_output import SourceConfigOutput
from mixpeek.models.source_details import SourceDetails
from mixpeek.models.source_enrichment_config import SourceEnrichmentConfig
from mixpeek.models.source_filters_input import SourceFiltersInput
from mixpeek.models.source_filters_output import SourceFiltersOutput
from mixpeek.models.source_type import SourceType
from mixpeek.models.sparse_vector import SparseVector
from mixpeek.models.spectral_params import SpectralParams
from mixpeek.models.spending_caps_response import SpendingCapsResponse
from mixpeek.models.split_method import SplitMethod
from mixpeek.models.stage_breakdown_response import StageBreakdownResponse
from mixpeek.models.stage_cache_behavior import StageCacheBehavior
from mixpeek.models.stage_cache_behavior1 import StageCacheBehavior1
from mixpeek.models.stage_category import StageCategory
from mixpeek.models.stage_config import StageConfig
from mixpeek.models.stage_instance_config import StageInstanceConfig
from mixpeek.models.stage_params_aggregate import StageParamsAggregate
from mixpeek.models.stage_params_api_call import StageParamsApiCall
from mixpeek.models.stage_params_attribute_filter import StageParamsAttributeFilter
from mixpeek.models.stage_params_cluster import StageParamsCluster
from mixpeek.models.stage_params_code_execution import StageParamsCodeExecution
from mixpeek.models.stage_params_document_enrich import StageParamsDocumentEnrich
from mixpeek.models.stage_params_external_web_search import StageParamsExternalWebSearch
from mixpeek.models.stage_params_feature_search import StageParamsFeatureSearch
from mixpeek.models.stage_params_group_by import StageParamsGroupBy
from mixpeek.models.stage_params_json_transform import StageParamsJsonTransform
from mixpeek.models.stage_params_llm_enrich import StageParamsLlmEnrich
from mixpeek.models.stage_params_llm_filter import StageParamsLlmFilter
from mixpeek.models.stage_params_mmr import StageParamsMmr
from mixpeek.models.stage_params_query_expand import StageParamsQueryExpand
from mixpeek.models.stage_params_rag_prepare import StageParamsRagPrepare
from mixpeek.models.stage_params_rerank import StageParamsRerank
from mixpeek.models.stage_params_sample import StageParamsSample
from mixpeek.models.stage_params_sort_attribute import StageParamsSortAttribute
from mixpeek.models.stage_params_sort_relevance import StageParamsSortRelevance
from mixpeek.models.stage_params_sql_lookup import StageParamsSqlLookup
from mixpeek.models.stage_params_summarize import StageParamsSummarize
from mixpeek.models.stage_params_taxonomy_enrich import StageParamsTaxonomyEnrich
from mixpeek.models.stage_params_web_scrape import StageParamsWebScrape
from mixpeek.models.stage_performance_input import StagePerformanceInput
from mixpeek.models.stage_performance_metrics import StagePerformanceMetrics
from mixpeek.models.stage_performance_output import StagePerformanceOutput
from mixpeek.models.stage_progress import StageProgress
from mixpeek.models.stage_statistics import StageStatistics
from mixpeek.models.stage_type import StageType
from mixpeek.models.stage_types_content_input import StageTypesContentInput
from mixpeek.models.stage_types_document_reference import StageTypesDocumentReference
from mixpeek.models.stage_types_feature_search_config import StageTypesFeatureSearchConfig
from mixpeek.models.stage_types_fusion_strategy import StageTypesFusionStrategy
from mixpeek.models.stage_types_on_empty_behavior import StageTypesOnEmptyBehavior
from mixpeek.models.start_evaluation_request import StartEvaluationRequest
from mixpeek.models.start_evaluation_response import StartEvaluationResponse
from mixpeek.models.start_migration_request import StartMigrationRequest
from mixpeek.models.start_migration_response import StartMigrationResponse
from mixpeek.models.step_analytics_config_input import StepAnalyticsConfigInput
from mixpeek.models.step_analytics_config_output import StepAnalyticsConfigOutput
from mixpeek.models.step_info import StepInfo
from mixpeek.models.step_key_source import StepKeySource
from mixpeek.models.step_transition_request import StepTransitionRequest
from mixpeek.models.step_transition_response import StepTransitionResponse
from mixpeek.models.storage_connection_create_request import StorageConnectionCreateRequest
from mixpeek.models.storage_connection_list_response import StorageConnectionListResponse
from mixpeek.models.storage_connection_model import StorageConnectionModel
from mixpeek.models.storage_connection_test_response import StorageConnectionTestResponse
from mixpeek.models.storage_connection_update_request import StorageConnectionUpdateRequest
from mixpeek.models.storage_metric import StorageMetric
from mixpeek.models.storage_provider import StorageProvider
from mixpeek.models.storage_statistics import StorageStatistics
from mixpeek.models.structured_data_config import StructuredDataConfig
from mixpeek.models.submit_batch_request import SubmitBatchRequest
from mixpeek.models.submit_feedback_request import SubmitFeedbackRequest
from mixpeek.models.submit_feedback_response import SubmitFeedbackResponse
from mixpeek.models.suitable_collection import SuitableCollection
from mixpeek.models.sync_comparison_response import SyncComparisonResponse
from mixpeek.models.sync_config_metric import SyncConfigMetric
from mixpeek.models.sync_configuration_model import SyncConfigurationModel
from mixpeek.models.sync_create_request import SyncCreateRequest
from mixpeek.models.sync_health_metric import SyncHealthMetric
from mixpeek.models.sync_list_response import SyncListResponse
from mixpeek.models.sync_mode import SyncMode
from mixpeek.models.sync_performance_response import SyncPerformanceResponse
from mixpeek.models.sync_run_metric import SyncRunMetric
from mixpeek.models.sync_update_request import SyncUpdateRequest
from mixpeek.models.task_progress import TaskProgress
from mixpeek.models.task_response import TaskResponse
from mixpeek.models.task_response_inputs_inner import TaskResponseInputsInner
from mixpeek.models.task_status_enum import TaskStatusEnum
from mixpeek.models.task_status_update_request import TaskStatusUpdateRequest
from mixpeek.models.task_type import TaskType
from mixpeek.models.taxonomy_application_config_input import TaxonomyApplicationConfigInput
from mixpeek.models.taxonomy_application_config_output import TaxonomyApplicationConfigOutput
from mixpeek.models.taxonomy_execution_mode import TaxonomyExecutionMode
from mixpeek.models.taxonomy_list_stats import TaxonomyListStats
from mixpeek.models.taxonomy_model_input import TaxonomyModelInput
from mixpeek.models.taxonomy_model_output import TaxonomyModelOutput
from mixpeek.models.taxonomy_options import TaxonomyOptions
from mixpeek.models.taxonomy_response import TaxonomyResponse
from mixpeek.models.template_mode import TemplateMode
from mixpeek.models.template_scope import TemplateScope
from mixpeek.models.template_type import TemplateType
from mixpeek.models.terminate_session_response import TerminateSessionResponse
from mixpeek.models.text_extractor_params import TextExtractorParams
from mixpeek.models.text_index_params import TextIndexParams
from mixpeek.models.text_query_input import TextQueryInput
from mixpeek.models.text_query_input1 import TextQueryInput1
from mixpeek.models.text_split_strategy import TextSplitStrategy
from mixpeek.models.theme_config import ThemeConfig
from mixpeek.models.tier_diagnostic import TierDiagnostic
from mixpeek.models.tier_task_info import TierTaskInfo
from mixpeek.models.tigris_access_key_credentials import TigrisAccessKeyCredentials
from mixpeek.models.tigris_config import TigrisConfig
from mixpeek.models.time_range_input import TimeRangeInput
from mixpeek.models.tokenizer_type import TokenizerType
from mixpeek.models.tool_info import ToolInfo
from mixpeek.models.transition_path import TransitionPath
from mixpeek.models.trigger_action_type import TriggerActionType
from mixpeek.models.trigger_collection_request import TriggerCollectionRequest
from mixpeek.models.trigger_collection_response import TriggerCollectionResponse
from mixpeek.models.trigger_execution_config import TriggerExecutionConfig
from mixpeek.models.trigger_execution_history import TriggerExecutionHistory
from mixpeek.models.trigger_execution_history_item import TriggerExecutionHistoryItem
from mixpeek.models.trigger_history_request import TriggerHistoryRequest
from mixpeek.models.trigger_tier_request import TriggerTierRequest
from mixpeek.models.url_patterns import URLPatterns
from mixpeek.models.unified_extractor_list_response import UnifiedExtractorListResponse
from mixpeek.models.unified_extractor_response import UnifiedExtractorResponse
from mixpeek.models.unique_key_config import UniqueKeyConfig
from mixpeek.models.update_namespace_request import UpdateNamespaceRequest
from mixpeek.models.update_object_request import UpdateObjectRequest
from mixpeek.models.update_preferences_request import UpdatePreferencesRequest
from mixpeek.models.update_published_retriever_request import UpdatePublishedRetrieverRequest
from mixpeek.models.update_reminder_preferences_request import UpdateReminderPreferencesRequest
from mixpeek.models.update_secret_request import UpdateSecretRequest
from mixpeek.models.update_spending_caps_request import UpdateSpendingCapsRequest
from mixpeek.models.upload_list_stats import UploadListStats
from mixpeek.models.upload_performance_metric import UploadPerformanceMetric
from mixpeek.models.upload_performance_response import UploadPerformanceResponse
from mixpeek.models.upload_response import UploadResponse
from mixpeek.models.usage_breakdown_response import UsageBreakdownResponse
from mixpeek.models.usage_metric import UsageMetric
from mixpeek.models.usage_statistics import UsageStatistics
from mixpeek.models.user_create_request import UserCreateRequest
from mixpeek.models.user_role import UserRole
from mixpeek.models.user_status import UserStatus
from mixpeek.models.user_update_request import UserUpdateRequest
from mixpeek.models.uuid_index_params import UuidIndexParams
from mixpeek.models.validate_migration_request import ValidateMigrationRequest
from mixpeek.models.validate_migration_response import ValidateMigrationResponse
from mixpeek.models.validate_result import ValidateResult
from mixpeek.models.validation_error import ValidationError
from mixpeek.models.validation_error_loc_inner import ValidationErrorLocInner
from mixpeek.models.validation_result import ValidationResult
from mixpeek.models.value import Value
from mixpeek.models.vector_based_config_input import VectorBasedConfigInput
from mixpeek.models.vector_based_config_output import VectorBasedConfigOutput
from mixpeek.models.vector_data_type import VectorDataType
from mixpeek.models.vector_index import VectorIndex
from mixpeek.models.vector_index_definition import VectorIndexDefinition
from mixpeek.models.vector_purpose import VectorPurpose
from mixpeek.models.vector_type import VectorType
from mixpeek.models.vectors import Vectors
from mixpeek.models.verify_password_request import VerifyPasswordRequest
from mixpeek.models.verify_password_response import VerifyPasswordResponse
from mixpeek.models.web_scraper_extractor_params import WebScraperExtractorParams
from mixpeek.models.webhook_channel_input import WebhookChannelInput
from mixpeek.models.webhook_channel_output import WebhookChannelOutput
from mixpeek.models.webhook_config import WebhookConfig
from mixpeek.models.webhook_event_type import WebhookEventType
from mixpeek.models.webhook_input import WebhookInput
from mixpeek.models.webhook_output import WebhookOutput
from mixpeek.models.weight_learning_config import WeightLearningConfig



# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool
from typing import Any, ClassVar, Dict, List, Optional
from mixpeek.models.pagination import Pagination
from typing import Optional, Set
from typing_extensions import Self

class ExecuteRetrieverRequest(BaseModel):
    """
    Request to execute a retriever with optional streaming support.  Inherits all fields from RetrieverExecutionRequest including: - inputs: Runtime input values matching the retriever's input_schema - pagination: Pagination configuration (cursor, offset, etc.) - stream: Enable SSE streaming for real-time stage updates  Streaming Execution (stream=True):     When streaming is enabled, the response uses Server-Sent Events (SSE) format     with Content-Type: text/event-stream. Each stage emits events as it executes:      Event Types:     - stage_start: Emitted when a stage begins execution     - stage_complete: Emitted when a stage finishes with results     - stage_error: Emitted if a stage encounters an error     - execution_complete: Emitted after all stages finish successfully     - execution_error: Emitted if the entire execution fails      Each event is a StreamStageEvent containing:     - event_type: The type of event     - execution_id: Unique execution identifier     - stage_name: Human-readable stage name     - stage_index: Zero-based stage position     - total_stages: Total number of stages     - documents: Intermediate results (for stage_complete)     - statistics: Stage metrics (duration, counts, etc.)     - budget_used: Cumulative resource consumption      Example streaming client:     ```python     response = requests.post(         '/v1/retrievers/{id}/execute',         json={'inputs': {...}, 'stream': True},         stream=True     )     for line in response.iter_lines():         if line.startswith(b'data: '):             event = json.loads(line[6:])             print(f\"{event['event_type']}: {event.get('stage_name')}\")     ```  Standard Execution (stream=False, default):     Returns a single ExecuteRetrieverResponse with final documents,     pagination, and aggregate statistics after all stages complete.
    """ # noqa: E501
    inputs: Optional[Dict[str, Any]] = Field(default=None, description="Runtime inputs for the retriever mapped to the input schema. Keys must match the retriever's input_schema field names. Values depend on field types (text, vector, filters, etc.). REQUIRED unless all retriever inputs have defaults.   Common input keys: - 'query': Text search query - 'embedding': Pre-computed vector for search - 'top_k': Number of results to return - 'min_score': Minimum relevance threshold - Any custom fields defined in input_schema   **Template Syntax** (Jinja2):  Namespaces (uppercase or lowercase): - `INPUT` / `input`: Query inputs (e.g., `{{INPUT.query}}`) - `DOC` / `doc`: Document fields (e.g., `{{DOC.payload.title}}`) - `CONTEXT` / `context`: Execution context - `STAGE` / `stage`: Stage configuration - `SECRET` / `secret`: Vault secrets (e.g., `{{SECRET.api_key}}`)  Accessing Data: - Dot notation: `{{DOC.payload.metadata.title}}` - Bracket notation: `{{DOC.payload['special-key']}}` - Array index: `{{DOC.items[0]}}`, `{{DOC.tags[2]}}` - Array first/last: `{{DOC.items | first}}`, `{{DOC.items | last}}`  Array Operations: - Iterate: `{% for item in DOC.tags %}{{item}}{% endfor %}` - Extract key: `{{DOC.items | map(attribute='name') | list}}` - Join: `{{DOC.tags | join(', ')}}` - Length: `{{DOC.items | length}}` - Slice: `{{DOC.items[:5]}}`  Conditionals: - If: `{% if DOC.status == 'active' %}...{% endif %}` - If-else: `{% if DOC.score > 0.8 %}high{% else %}low{% endif %}` - Ternary: `{{'yes' if DOC.enabled else 'no'}}`  Built-in Functions: `max`, `min`, `abs`, `round`, `ceil`, `floor` Custom Filters: `slugify` (URL-safe), `bool` (truthy coercion), `tojson` (JSON encode)  S3 URLs: Internal S3 URLs (s3://bucket/key) are automatically presigned when accessed via DOC namespace.")
    pagination: Optional[Pagination] = None
    stream: Optional[StrictBool] = Field(default=False, description="Enable streaming execution to receive real-time stage updates via Server-Sent Events (SSE). NOT REQUIRED - defaults to False for standard execution.   When stream=True: - Response uses text/event-stream content type - Each stage completion emits a StreamStageEvent - Events include: stage_start, stage_complete, stage_error, execution_complete - Clients receive intermediate results and statistics as stages execute - Useful for progress tracking, debugging, and partial result display   When stream=False (default): - Response returns after all stages complete - Returns a single RetrieverExecutionResponse with final results - Lower overhead for simple queries   Use streaming when: - You want to show real-time progress to users - You need to display intermediate results - Pipeline has many stages or long-running operations - Debugging or monitoring pipeline performance   Example streaming client (JavaScript): ```javascript const eventSource = new EventSource('/v1/retrievers/ret_123/execute?stream=true'); eventSource.onmessage = (event) => {   const stageEvent = JSON.parse(event.data);   if (stageEvent.event_type === 'stage_complete') {     console.log(`Stage ${stageEvent.stage_name} completed`);     console.log(`Documents: ${stageEvent.documents.length}`);   } }; ```   Example streaming client (Python): ```python import requests response = requests.post('/v1/retrievers/ret_123/execute',                         json={'inputs': {...}, 'stream': True},                         stream=True) for line in response.iter_lines():     if line.startswith(b'data: '):         event = json.loads(line[6:])         print(f\"Stage {event['stage_name']}: {event['event_type']}\") ```")
    __properties: ClassVar[List[str]] = ["inputs", "pagination", "stream"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ExecuteRetrieverRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of pagination
        if self.pagination:
            _dict['pagination'] = self.pagination.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ExecuteRetrieverRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "inputs": obj.get("inputs"),
            "pagination": Pagination.from_dict(obj["pagination"]) if obj.get("pagination") is not None else None,
            "stream": obj.get("stream") if obj.get("stream") is not None else False
        })
        return _obj





# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.webhook_input import WebhookInput

class TestWebhookInput(unittest.TestCase):
    """WebhookInput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WebhookInput:
        """Test WebhookInput
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WebhookInput`
        """
        model = WebhookInput()
        if include_optional:
            return WebhookInput(
                webhook_id = 'wh_62ECB020842930cc',
                webhook_name = '0',
                internal_id = '',
                event_types = [
                    'object.created'
                    ],
                channels = [
                    mixpeek.models.webhook_channel.WebhookChannel(
                        channel = null, 
                        configs = null, )
                    ],
                is_active = True,
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return WebhookInput(
                webhook_name = '0',
                event_types = [
                    'object.created'
                    ],
                channels = [
                    mixpeek.models.webhook_channel.WebhookChannel(
                        channel = null, 
                        configs = null, )
                    ],
        )
        """

    def testWebhookInput(self):
        """Test WebhookInput"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.api.bucket_syncs_api import BucketSyncsApi


class TestBucketSyncsApi(unittest.TestCase):
    """BucketSyncsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = BucketSyncsApi()

    def tearDown(self) -> None:
        pass

    def test_create_sync_configuration_buckets(self) -> None:
        """Test case for create_sync_configuration_buckets

        Create Sync Configuration
        """
        pass

    def test_delete_sync_configuration_buckets_id_config(self) -> None:
        """Test case for delete_sync_configuration_buckets_id_config

        Delete Sync Configuration
        """
        pass

    def test_get_sync_configuration_buckets_id_config(self) -> None:
        """Test case for get_sync_configuration_buckets_id_config

        Get Sync Configuration
        """
        pass

    def test_list_sync_configurations_buckets(self) -> None:
        """Test case for list_sync_configurations_buckets

        List Sync Configurations
        """
        pass

    def test_pause_sync_configuration_buckets_id_config(self) -> None:
        """Test case for pause_sync_configuration_buckets_id_config

        Pause Sync Configuration
        """
        pass

    def test_resume_sync_configuration_buckets_id_config(self) -> None:
        """Test case for resume_sync_configuration_buckets_id_config

        Resume Sync Configuration
        """
        pass

    def test_trigger_sync_configuration_buckets_id_config(self) -> None:
        """Test case for trigger_sync_configuration_buckets_id_config

        Trigger Sync Configuration
        """
        pass

    def test_update_sync_configuration_buckets_id_config(self) -> None:
        """Test case for update_sync_configuration_buckets_id_config

        Update Sync Configuration
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from mixpeek.models.hierarchical_enrichment_style import HierarchicalEnrichmentStyle
from mixpeek.models.logical_operator_input import LogicalOperatorInput
from mixpeek.models.taxonomy_execution_mode import TaxonomyExecutionMode
from typing import Optional, Set
from typing_extensions import Self

class TaxonomyApplicationConfigInput(BaseModel):
    """
    Configuration block that attaches a taxonomy to a collection.  Supports execution phase ordering for unified post-processing with taxonomies, clusters, and alerts.
    """ # noqa: E501
    taxonomy_id: StrictStr = Field(description="ID of the `TaxonomyModel` to execute.")
    execution_mode: Optional[TaxonomyExecutionMode] = Field(default=None, description="Execution mode for taxonomy enrichment. Materializes results during ingestion.")
    target_collection_id: Optional[StrictStr] = Field(default=None, description="Optional collection to persist results into when `execution_mode` is 'materialize'. If omitted, the source collection is updated in-place.")
    scroll_filters: Optional[LogicalOperatorInput] = Field(default=None, description="Additional filters applied when scrolling the source collection before enrichment.")
    execution_phase: Optional[Annotated[int, Field(le=3, strict=True, ge=1)]] = Field(default=1, description="Which phase this taxonomy runs in. Default: 1 (TAXONOMY phase, runs first). Valid values: 1=TAXONOMY, 2=CLUSTER, 3=ALERT. Lower phases run earlier.")
    priority: Optional[Annotated[int, Field(le=1000, strict=True, ge=0)]] = Field(default=0, description="Priority within the execution phase (higher = runs first)")
    hierarchical_enrichment_style: Optional[HierarchicalEnrichmentStyle] = Field(default=None, description="For hierarchical taxonomies, controls how enrichment fields are structured. 'full_chain': Each tier writes to tier-prefixed fields (tier1_id, tier2_id, etc.). 'best_match': Only deepest match stored (category_id, category_name, path[]). 'combined' (default): Both full chain AND best match summary fields.")
    additional_properties: Dict[str, Any] = {}
    __properties: ClassVar[List[str]] = ["taxonomy_id", "execution_mode", "target_collection_id", "scroll_filters", "execution_phase", "priority", "hierarchical_enrichment_style"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TaxonomyApplicationConfigInput from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * Fields in `self.additional_properties` are added to the output dict.
        """
        excluded_fields: Set[str] = set([
            "additional_properties",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of scroll_filters
        if self.scroll_filters:
            _dict['scroll_filters'] = self.scroll_filters.to_dict()
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TaxonomyApplicationConfigInput from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "taxonomy_id": obj.get("taxonomy_id"),
            "execution_mode": obj.get("execution_mode"),
            "target_collection_id": obj.get("target_collection_id"),
            "scroll_filters": LogicalOperatorInput.from_dict(obj["scroll_filters"]) if obj.get("scroll_filters") is not None else None,
            "execution_phase": obj.get("execution_phase") if obj.get("execution_phase") is not None else 1,
            "priority": obj.get("priority") if obj.get("priority") is not None else 0,
            "hierarchical_enrichment_style": obj.get("hierarchical_enrichment_style")
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj





# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List
from mixpeek.models.api_analytics_models_time_range import ApiAnalyticsModelsTimeRange
from mixpeek.models.interaction_tuning_recommendation import InteractionTuningRecommendation
from typing import Optional, Set
from typing_extensions import Self

class InteractionTuningResponse(BaseModel):
    """
    Response for interaction tuning analysis.
    """ # noqa: E501
    retriever_id: StrictStr = Field(description="Retriever identifier")
    analysis_period: ApiAnalyticsModelsTimeRange = Field(description="Analysis period")
    recommendations: List[InteractionTuningRecommendation] = Field(description="Tuning recommendations")
    current_performance: Dict[str, Any] = Field(description="Current performance baseline")
    __properties: ClassVar[List[str]] = ["retriever_id", "analysis_period", "recommendations", "current_performance"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of InteractionTuningResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of analysis_period
        if self.analysis_period:
            _dict['analysis_period'] = self.analysis_period.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in recommendations (list)
        _items = []
        if self.recommendations:
            for _item_recommendations in self.recommendations:
                if _item_recommendations:
                    _items.append(_item_recommendations.to_dict())
            _dict['recommendations'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of InteractionTuningResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "retriever_id": obj.get("retriever_id"),
            "analysis_period": ApiAnalyticsModelsTimeRange.from_dict(obj["analysis_period"]) if obj.get("analysis_period") is not None else None,
            "recommendations": [InteractionTuningRecommendation.from_dict(_item) for _item in obj["recommendations"]] if obj.get("recommendations") is not None else None,
            "current_performance": obj.get("current_performance")
        })
        return _obj





# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.api.published_retrievers_api import PublishedRetrieversApi


class TestPublishedRetrieversApi(unittest.TestCase):
    """PublishedRetrieversApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PublishedRetrieversApi()

    def tearDown(self) -> None:
        pass

    def test_check_name_availability_retrievers_id_publish(self) -> None:
        """Test case for check_name_availability_retrievers_id_publish

        Check Name Availability
        """
        pass

    def test_get_organization_publish_stats_retrievers(self) -> None:
        """Test case for get_organization_publish_stats_retrievers

        Get Organization Publish Stats
        """
        pass

    def test_get_published_retriever_id_publish(self) -> None:
        """Test case for get_published_retriever_id_publish

        Get Published Retriever
        """
        pass

    def test_list_published_retrievers(self) -> None:
        """Test case for list_published_retrievers

        List Published Retrievers
        """
        pass

    def test_publish_retriever(self) -> None:
        """Test case for publish_retriever

        Publish Retriever
        """
        pass

    def test_unpublish_retriever_id_publish(self) -> None:
        """Test case for unpublish_retriever_id_publish

        Unpublish Retriever
        """
        pass

    def test_update_published_retriever_id_publish(self) -> None:
        """Test case for update_published_retriever_id_publish

        Update Published Retriever
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.algorithm_params import AlgorithmParams

class TestAlgorithmParams(unittest.TestCase):
    """AlgorithmParams unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AlgorithmParams:
        """Test AlgorithmParams
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AlgorithmParams`
        """
        model = AlgorithmParams()
        if include_optional:
            return AlgorithmParams(
                n_clusters = 2.0,
                max_iter = 1.0,
                random_state = 56,
                n_init = 1.0,
                tol = 1.337,
                init = 'k-means++',
                verbose = 0.0,
                copy_x = True,
                algorithm = 'auto',
                eps = 1.337,
                min_samples = 2.0,
                metric = 'minkowski',
                metric_params = mixpeek.models.metric_params.Metric Params(),
                leaf_size = 1.0,
                p = 1.337,
                n_jobs = 56,
                min_cluster_size = 1.337,
                cluster_selection_epsilon = 0.0,
                max_cluster_size = 1.0,
                alpha = 1.337,
                cluster_selection_method = 'eom',
                allow_single_cluster = True,
                prediction_data = True,
                match_reference_implementation = True,
                affinity = 'rbf',
                memory = '',
                connectivity = None,
                compute_full_tree = 'auto',
                linkage = 'ward',
                distance_threshold = 1.337,
                compute_distances = True,
                eigen_solver = '',
                n_components = 1.0,
                gamma = 1.337,
                n_neighbors = 1.0,
                eigen_tol = 0.0,
                assign_labels = 'kmeans',
                degree = 1.337,
                coef0 = 1.337,
                kernel_params = mixpeek.models.kernel_params.Kernel Params(),
                covariance_type = 'full',
                reg_covar = 0.0,
                init_params = 'kmeans',
                weights_init = [
                    null
                    ],
                means_init = [
                    null
                    ],
                precisions_init = [
                    null
                    ],
                warm_start = True,
                verbose_interval = 1.0,
                bandwidth = 1.337,
                seeds = [
                    [
                        1.337
                        ]
                    ],
                bin_seeding = True,
                min_bin_freq = 1.0,
                cluster_all = True,
                max_eps = 1.337,
                cluster_method = 'xi',
                xi = 0.0,
                predecessor_correction = True
            )
        else:
            return AlgorithmParams(
        )
        """

    def testAlgorithmParams(self):
        """Test AlgorithmParams"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class FacetFieldConfig(BaseModel):
    """
    Configuration for a single facet field.  Faceting counts unique values for a field, enabling faceted search interfaces (e.g., \"Show 45 results in 'Sports', 23 in 'Music'\").  ┌─────────────────────────────────────────────────────────────────────────────┐ │ IMPORTANT: INDEX REQUIREMENT                                                │ │                                                                             │ │ The field MUST have a keyword index in Qdrant for faceting to work.         │ │ Fields are automatically indexed during collection creation for common      │ │ metadata fields. For custom fields, ensure indexing is configured.          │ │                                                                             │ │ Without an index, faceting will fail with an error.                         │ └─────────────────────────────────────────────────────────────────────────────┘  Example:     ```json     {         \"key\": \"metadata.category\",         \"limit\": 10,         \"exact\": false     }     ```
    """ # noqa: E501
    key: StrictStr = Field(description="REQUIRED. Field path to facet on (e.g., 'metadata.category', 'status'). Supports nested fields using dot notation. The field MUST have a keyword index in Qdrant - faceting will fail without it. Common indexed fields: metadata.*, status, collection_id, source_object_id.")
    limit: Optional[Annotated[int, Field(le=1000, strict=True, ge=1)]] = Field(default=10, description="OPTIONAL. Maximum number of unique values to return (default: 10). Results are sorted by count descending, then by value ascending. Higher limits increase response size but provide more comprehensive facets. Common values: 5 (compact), 10 (standard), 20-50 (detailed).")
    exact: Optional[StrictBool] = Field(default=False, description="OPTIONAL. Use exact counts instead of approximate (default: False). - False (default): Fast approximate counts, suitable for most UIs.   Approximate counts are accurate enough for display purposes. - True: Slower but precise counts, useful for debugging or analytics.   Use when exact numbers matter (e.g., reports, dashboards).")
    __properties: ClassVar[List[str]] = ["key", "limit", "exact"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of FacetFieldConfig from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of FacetFieldConfig from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "key": obj.get("key"),
            "limit": obj.get("limit") if obj.get("limit") is not None else 10,
            "exact": obj.get("exact") if obj.get("exact") is not None else False
        })
        return _obj





# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional, Union
from mixpeek.models.generation_config import GenerationConfig
from mixpeek.models.response_shape1 import ResponseShape1
from mixpeek.models.split_method import SplitMethod
from typing import Optional, Set
from typing_extensions import Self

class MultimodalExtractorParams(BaseModel):
    """
    Parameters for the multimodal extractor.  The multimodal extractor processes video, audio, image, text, and GIF content in a unified embedding space. Videos/GIFs/Audio are decomposed into segments with transcription, visual analysis (video only), OCR, and embeddings. Images and text are embedded directly without decomposition.  **When to Use**:     - Video content libraries requiring searchable segments     - Audio content (podcasts, lectures, music) requiring transcription and search     - Media platforms with search across spoken and visual content     - Educational content with lecture videos and demonstrations     - Surveillance/security footage requiring event detection     - Social media platforms with user-generated video content     - Broadcasting/streaming services with large video catalogs     - Training video repositories with instructional content     - Marketing/advertising analytics for video campaigns  **When NOT to Use**:     - Static image collections → Use image_extractor instead     - Very short videos (<5 seconds) → Overhead not worth it     - Real-time live streams → Use specialized streaming extractors     - Extremely high-resolution videos (8K+) → Consider downsampling first  **Decomposition Methods**:      | Method | Use Case | Accuracy | Segments/Min | Best For |     |--------|----------|----------|--------------|----------|     | **TIME** | Fixed intervals | N/A | 60/interval_sec | General purpose, audio/video chunking |     | **SCENE** | Visual changes | 85-90% | Variable (2-20) | Movies, dynamic content (video only) |     | **SILENCE** | Audio pauses | 80-85% | Variable (5-30) | Lectures, presentations, audio/video |  **Feature Extraction Options**:     - Transcription: Speech-to-text using Whisper (95%+ accuracy)     - Multimodal Embeddings: Unified embeddings from Vertex AI (1408D) for video/image/gif/text     - Transcription Embeddings: Text embeddings from E5-Large (1024D)     - OCR: Text extraction from video frames using Gemini Vision     - Descriptions: AI-generated segment summaries using Gemini     - Thumbnails: Visual preview images for each segment  **Performance Characteristics**:     - Processing Speed: 0.5-2x realtime (depends on features enabled)     - Example: 10min video → 5-20 minutes processing time     - Transcription: ~200ms per second of audio     - Visual Embedding: ~50ms per segment     - OCR: ~300ms per segment     - Description: ~2s per segment (if enabled)  Requirements:     - video URL: REQUIRED (accessible video file)     - All feature parameters: OPTIONAL (defaults provided)
    """ # noqa: E501
    extractor_type: Optional[StrictStr] = Field(default='multimodal_extractor', description="Discriminator field for parameter type identification. Must be 'multimodal_extractor'.")
    split_method: Optional[SplitMethod] = Field(default=None, description="The PRIMARY control for video splitting strategy. This determines which splitting method is used.")
    description_prompt: Optional[StrictStr] = Field(default='Describe the video segment in detail.', description="The prompt to use for description generation.")
    time_split_interval: Optional[StrictInt] = Field(default=10, description="Interval in seconds for 'time' splitting. Used when split_method='time'.")
    silence_db_threshold: Optional[StrictInt] = Field(default=None, description="The decibel level below which audio is considered silent. Used when split_method='silence'. Recommended value: -40 (auto-applied if not specified). Lower values (e.g., -50) detect more silence, higher values (e.g., -30) detect less.")
    scene_detection_threshold: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="The threshold for scene detection (0.0-1.0). Used when split_method='scene'. Recommended value: 0.5 (auto-applied if not specified). Lower values (e.g., 0.3) detect more scenes, higher values (e.g., 0.7) detect fewer scenes.")
    run_transcription: Optional[StrictBool] = Field(default=False, description="Whether to run transcription on video segments.")
    transcription_language: Optional[StrictStr] = Field(default='en', description="The language of the transcription. Used when run_transcription is True.")
    run_video_description: Optional[StrictBool] = Field(default=False, description="Whether to generate descriptions for video segments. OPTIMIZED: Defaults to False as descriptions add 1-2 minutes. Enable only when needed.")
    run_transcription_embedding: Optional[StrictBool] = Field(default=False, description="Whether to generate embeddings for transcriptions. Useful for semantic search over spoken content.")
    run_multimodal_embedding: Optional[StrictBool] = Field(default=True, description="Whether to generate multimodal embeddings for all content types (video/image/gif/text). Uses Google Vertex AI to create unified 1408D embeddings in a shared semantic space. Useful for cross-modal semantic search across all media types.")
    run_ocr: Optional[StrictBool] = Field(default=False, description="Whether to run OCR to extract text from video frames. OPTIMIZED: Defaults to False as OCR adds significant processing time. Enable only when text extraction from video is required.")
    sensitivity: Optional[StrictStr] = Field(default='low', description="The sensitivity of the scene detection.")
    enable_thumbnails: Optional[StrictBool] = Field(default=True, description="Whether to generate thumbnail images for video segments and images. Thumbnails provide visual previews for navigation and UI display. For videos: Extracts a frame from each segment. For images: Creates an optimized thumbnail version. ")
    use_cdn: Optional[StrictBool] = Field(default=False, description="Whether to use CloudFront CDN for thumbnail delivery. When True: Uploads to public bucket and returns CloudFront URLs. When False (default): Uploads to private bucket with presigned S3 URLs. Benefits of CDN: faster global delivery, permanent URLs, reduced bandwidth costs. Requires CLOUDFRONT_PUBLIC_DOMAIN to be configured in settings. Only applies when enable_thumbnails=True.")
    generation_config: Optional[GenerationConfig] = None
    response_shape: Optional[ResponseShape1] = None
    __properties: ClassVar[List[str]] = ["extractor_type", "split_method", "description_prompt", "time_split_interval", "silence_db_threshold", "scene_detection_threshold", "run_transcription", "transcription_language", "run_video_description", "run_transcription_embedding", "run_multimodal_embedding", "run_ocr", "sensitivity", "enable_thumbnails", "use_cdn", "generation_config", "response_shape"]

    @field_validator('extractor_type')
    def extractor_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['multimodal_extractor']):
            raise ValueError("must be one of enum values ('multimodal_extractor')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of MultimodalExtractorParams from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of generation_config
        if self.generation_config:
            _dict['generation_config'] = self.generation_config.to_dict()
        # override the default output from pydantic by calling `to_dict()` of response_shape
        if self.response_shape:
            _dict['response_shape'] = self.response_shape.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of MultimodalExtractorParams from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "extractor_type": obj.get("extractor_type") if obj.get("extractor_type") is not None else 'multimodal_extractor',
            "split_method": obj.get("split_method"),
            "description_prompt": obj.get("description_prompt") if obj.get("description_prompt") is not None else 'Describe the video segment in detail.',
            "time_split_interval": obj.get("time_split_interval") if obj.get("time_split_interval") is not None else 10,
            "silence_db_threshold": obj.get("silence_db_threshold"),
            "scene_detection_threshold": obj.get("scene_detection_threshold"),
            "run_transcription": obj.get("run_transcription") if obj.get("run_transcription") is not None else False,
            "transcription_language": obj.get("transcription_language") if obj.get("transcription_language") is not None else 'en',
            "run_video_description": obj.get("run_video_description") if obj.get("run_video_description") is not None else False,
            "run_transcription_embedding": obj.get("run_transcription_embedding") if obj.get("run_transcription_embedding") is not None else False,
            "run_multimodal_embedding": obj.get("run_multimodal_embedding") if obj.get("run_multimodal_embedding") is not None else True,
            "run_ocr": obj.get("run_ocr") if obj.get("run_ocr") is not None else False,
            "sensitivity": obj.get("sensitivity") if obj.get("sensitivity") is not None else 'low',
            "enable_thumbnails": obj.get("enable_thumbnails") if obj.get("enable_thumbnails") is not None else True,
            "use_cdn": obj.get("use_cdn") if obj.get("use_cdn") is not None else False,
            "generation_config": GenerationConfig.from_dict(obj["generation_config"]) if obj.get("generation_config") is not None else None,
            "response_shape": ResponseShape1.from_dict(obj["response_shape"]) if obj.get("response_shape") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt
from typing import Any, ClassVar, Dict, List
from mixpeek.models.failed_object_error import FailedObjectError
from mixpeek.models.object_response import ObjectResponse
from typing import Optional, Set
from typing_extensions import Self

class CreateObjectsBatchResponse(BaseModel):
    """
    Response model for batch object creation with partial success support.  This endpoint uses partial success: valid objects are created even if some fail. Failed objects are tracked separately so users can fix and retry them.
    """ # noqa: E501
    succeeded: List[ObjectResponse] = Field(description="List of successfully created objects")
    failed: List[FailedObjectError] = Field(description="List of objects that failed to create with error details")
    total_requested: StrictInt = Field(description="Total number of objects in the batch request")
    succeeded_count: StrictInt = Field(description="Number of objects successfully created")
    failed_count: StrictInt = Field(description="Number of objects that failed")
    __properties: ClassVar[List[str]] = ["succeeded", "failed", "total_requested", "succeeded_count", "failed_count"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CreateObjectsBatchResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in succeeded (list)
        _items = []
        if self.succeeded:
            for _item_succeeded in self.succeeded:
                if _item_succeeded:
                    _items.append(_item_succeeded.to_dict())
            _dict['succeeded'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in failed (list)
        _items = []
        if self.failed:
            for _item_failed in self.failed:
                if _item_failed:
                    _items.append(_item_failed.to_dict())
            _dict['failed'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CreateObjectsBatchResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "succeeded": [ObjectResponse.from_dict(_item) for _item in obj["succeeded"]] if obj.get("succeeded") is not None else None,
            "failed": [FailedObjectError.from_dict(_item) for _item in obj["failed"]] if obj.get("failed") is not None else None,
            "total_requested": obj.get("total_requested"),
            "succeeded_count": obj.get("succeeded_count"),
            "failed_count": obj.get("failed_count")
        })
        return _obj





# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from mixpeek.models.key_status import KeyStatus
from mixpeek.models.permission import Permission
from mixpeek.models.resource_scope_input import ResourceScopeInput
from typing import Optional, Set
from typing_extensions import Self

class APIKeyUpdateRequest(BaseModel):
    """
    Partial update payload for an API key.
    """ # noqa: E501
    name: Optional[Annotated[str, Field(min_length=1, strict=True, max_length=100)]] = Field(default=None, description="New key label.")
    description: Optional[Annotated[str, Field(strict=True, max_length=500)]] = Field(default=None, description="Updated description for the key.")
    permissions: Optional[List[Permission]] = Field(default=None, description="Replace existing permissions with the provided list.")
    scopes: Optional[List[ResourceScopeInput]] = Field(default=None, description="Replace existing scopes. Use empty list for global access.")
    rate_limit_override: Optional[Annotated[int, Field(strict=True, ge=1)]] = Field(default=None, description="Updated per-key rate limit override.")
    expires_at: Optional[datetime] = Field(default=None, description="New expiration timestamp. Use null to remove expiration.")
    status: Optional[KeyStatus] = Field(default=None, description="Manually set key status (e.g. revoke).")
    __properties: ClassVar[List[str]] = ["name", "description", "permissions", "scopes", "rate_limit_override", "expires_at", "status"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of APIKeyUpdateRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in scopes (list)
        _items = []
        if self.scopes:
            for _item_scopes in self.scopes:
                if _item_scopes:
                    _items.append(_item_scopes.to_dict())
            _dict['scopes'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of APIKeyUpdateRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "name": obj.get("name"),
            "description": obj.get("description"),
            "permissions": obj.get("permissions"),
            "scopes": [ResourceScopeInput.from_dict(_item) for _item in obj["scopes"]] if obj.get("scopes") is not None else None,
            "rate_limit_override": obj.get("rate_limit_override"),
            "expires_at": obj.get("expires_at"),
            "status": obj.get("status")
        })
        return _obj





# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from mixpeek.models.schema_mapping_input import SchemaMappingInput
from mixpeek.models.sync_mode import SyncMode
from typing import Optional, Set
from typing_extensions import Self

class SyncCreateRequest(BaseModel):
    """
    Request to create a bucket sync configuration.  Establishes automated synchronization between a storage connection and a bucket. The sync monitors the source path for changes and ingests files according to the specified mode and filters.  Supported Storage Providers:     - google_drive: Google Drive and Workspace shared drives     - s3: Amazon S3 and S3-compatible (MinIO, DigitalOcean Spaces, Wasabi)     - snowflake: Snowflake data warehouse tables (rows become objects)     - sharepoint: Microsoft SharePoint and OneDrive for Business     - tigris: Tigris globally distributed object storage  Robustness Features (built-in):     - Dead Letter Queue (DLQ): Failed objects tracked with 3 retries before quarantine     - Idempotent ingestion: Deduplication via (bucket_id, source_provider, source_object_id)     - Distributed locking: Prevents concurrent execution of same sync config     - Rate limit handling: Automatic backoff on provider 429 responses     - Metrics: Duration, files synced/failed, batches created, rate limit hits  Sync Modes:     - continuous: Real-time monitoring with polling interval     - one_time: Single bulk import then stops     - scheduled: Polling-based batch imports  Requirements:     - connection_id: REQUIRED, must be an existing connection     - source_path: REQUIRED, path must exist in the storage provider     - sync_mode: OPTIONAL, defaults to 'continuous'     - All other fields are OPTIONAL with sensible defaults
    """ # noqa: E501
    connection_id: StrictStr = Field(description="REQUIRED. Storage connection identifier to sync from. Must reference an existing connection created via POST /organizations/connections. The connection defines the storage provider and credentials. Supported providers: google_drive, s3, snowflake, sharepoint, tigris.")
    source_path: StrictStr = Field(description="REQUIRED. Source path within the storage provider to monitor and sync. Path format varies by provider: - s3/tigris: 'bucket-name/prefix' or 'bucket-name'. - google_drive: folder ID or path like '/Marketing/Assets'. - sharepoint: '/sites/SiteName/Shared Documents/folder'. - snowflake: 'DATABASE.SCHEMA.TABLE' or just 'TABLE' if defaults set.")
    sync_mode: Optional[SyncMode] = Field(default=None, description="Synchronization mode determining how files are monitored and ingested. OPTIONAL. Defaults to 'continuous'. 'continuous': Actively monitors for new files and syncs immediately. 'one_time': Performs a single sync of existing files then stops. 'scheduled': Syncs on polling intervals only.")
    file_filters: Optional[Dict[str, Any]] = Field(default=None, description="OPTIONAL. Filters to control which files are synced. When omitted, all files in source_path are synced. Supported filters: - include_patterns: Glob patterns to include (e.g., ['*.mp4', '*.mov']). - exclude_patterns: Glob patterns to exclude (e.g., ['*.tmp', '.DS_Store']). - extensions: File extensions to include (e.g., ['.mp4', '.jpg']). - min_size_bytes: Minimum file size in bytes. - max_size_bytes: Maximum file size in bytes. - modified_after: ISO datetime, only sync files modified after this time. - mime_types: List of MIME types to include (e.g., ['video/*', 'image/jpeg']).")
    schema_mapping: Optional[SchemaMappingInput] = Field(default=None, description="OPTIONAL. Defines how source data maps to bucket schema fields and blobs. When provided, enables structured extraction of metadata from the sync source. Keys are target bucket schema field names, values define the source extraction method.   **Blob Mappings** (target_type='blob'): Map files or URLs to blob fields. Use source.type='file' for the synced file itself, or source.type='column'/'metadata' for URLs.   **Field Mappings** (target_type='field'): Map metadata to schema fields. Source options by provider: - S3/Tigris: 'tag' (object tags), 'metadata' (x-amz-meta-*) - Snowflake: 'column' (table columns) - Google Drive: 'drive_property' (file properties) - All: 'filename_regex', 'folder_path', 'constant'   If omitted, default behavior depends on provider - typically maps file to 'content' blob.")
    polling_interval_seconds: Optional[Annotated[int, Field(le=900, strict=True, ge=30)]] = Field(default=300, description="Interval in seconds between polling checks for new files. OPTIONAL. Defaults to 300 seconds (5 minutes). Must be between 30 and 900 seconds (0.5 to 15 minutes). Only applies to 'continuous' and 'scheduled' sync modes. Lower values mean faster detection but higher API usage.")
    batch_size: Optional[Annotated[int, Field(le=100, strict=True, ge=1)]] = Field(default=50, description="Number of files to process in each batch during sync. OPTIONAL. Defaults to 50 files per batch. Must be between 1 and 100. Larger batches improve throughput but require more memory. Smaller batches provide more granular progress tracking.")
    skip_batch_submission: Optional[StrictBool] = Field(default=False, description="If True, sync objects to the bucket without creating or submitting batches for collection processing. Objects are created in the bucket but no tier processing is triggered. Useful for bulk data migration or when you want to manually control when processing occurs. OPTIONAL. Defaults to False (batches are created and submitted).")
    metadata: Optional[Dict[str, Any]] = Field(default=None, description="Optional custom metadata to attach to the sync configuration. NOT REQUIRED. Arbitrary key-value pairs for tagging and organization. Common uses: project tags, environment labels, cost centers. Maximum 50 keys, values must be JSON-serializable.")
    __properties: ClassVar[List[str]] = ["connection_id", "source_path", "sync_mode", "file_filters", "schema_mapping", "polling_interval_seconds", "batch_size", "skip_batch_submission", "metadata"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SyncCreateRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of schema_mapping
        if self.schema_mapping:
            _dict['schema_mapping'] = self.schema_mapping.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SyncCreateRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "connection_id": obj.get("connection_id"),
            "source_path": obj.get("source_path"),
            "sync_mode": obj.get("sync_mode"),
            "file_filters": obj.get("file_filters"),
            "schema_mapping": SchemaMappingInput.from_dict(obj["schema_mapping"]) if obj.get("schema_mapping") is not None else None,
            "polling_interval_seconds": obj.get("polling_interval_seconds") if obj.get("polling_interval_seconds") is not None else 300,
            "batch_size": obj.get("batch_size") if obj.get("batch_size") is not None else 50,
            "skip_batch_submission": obj.get("skip_batch_submission") if obj.get("skip_batch_submission") is not None else False,
            "metadata": obj.get("metadata")
        })
        return _obj





# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from mixpeek.models.task_status_enum import TaskStatusEnum
from typing import Optional, Set
from typing_extensions import Self

class StorageConnectionUpdateRequest(BaseModel):
    """
    Request payload for updating storage connection metadata.  Allows partial updates to connection metadata without changing credentials. Credentials can be updated via provider_config.  **What You Can Update:** - Connection name and description - Metadata tags - Status (active/suspended) - Provider credentials (via provider_config)  **Examples:** ```python # Update name and description {     \"name\": \"Updated Drive Name\",     \"description\": \"New description\" }  # Suspend connection {     \"status\": \"suspended\",     \"is_active\": False }  # Refresh credentials {     \"provider_config\": {         \"credentials\": {...}     } } ```
    """ # noqa: E501
    name: Optional[Annotated[str, Field(min_length=1, strict=True, max_length=100)]] = Field(default=None, description="OPTIONAL. New name for the connection. Must be unique within the organization if provided. Format: 1-100 characters.")
    description: Optional[Annotated[str, Field(strict=True, max_length=500)]] = Field(default=None, description="OPTIONAL. New description for the connection. Set to empty string to clear existing description. Format: Up to 500 characters.")
    metadata: Optional[Dict[str, Any]] = Field(default=None, description="OPTIONAL. New metadata dictionary. Replaces existing metadata entirely (partial updates not supported). Set to empty dict {} to clear all metadata.")
    status: Optional[TaskStatusEnum] = Field(default=None, description="OPTIONAL. New operational status. ACTIVE: Connection is healthy and ready for use. SUSPENDED: Temporarily disabled, credentials preserved. FAILED: Health checks failing. ARCHIVED: Permanently retired (cannot be reactivated).")
    is_active: Optional[StrictBool] = Field(default=None, description="OPTIONAL. Quick boolean flag for filtering. True when status is ACTIVE, False otherwise. Automatically maintained when status changes.")
    provider_config: Optional[Dict[str, Any]] = Field(default=None, description="OPTIONAL. Updated provider configuration including credentials. Replaces entire provider_config (partial updates not supported). SECURITY: Sensitive fields are encrypted at rest.")
    __properties: ClassVar[List[str]] = ["name", "description", "metadata", "status", "is_active", "provider_config"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of StorageConnectionUpdateRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of StorageConnectionUpdateRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "name": obj.get("name"),
            "description": obj.get("description"),
            "metadata": obj.get("metadata"),
            "status": obj.get("status"),
            "is_active": obj.get("is_active"),
            "provider_config": obj.get("provider_config")
        })
        return _obj





# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from mixpeek.models.task_progress import TaskProgress
from typing import Optional, Set
from typing_extensions import Self

class TierDiagnostic(BaseModel):
    """
    Diagnostic information for a single tier.
    """ # noqa: E501
    tier_num: StrictInt = Field(description="Tier number")
    task_id: Optional[StrictStr] = Field(default=None, description="Task ID for this tier")
    status: StrictStr = Field(description="Tier status (PENDING, PROCESSING, COMPLETED, FAILED)")
    started_at: Optional[datetime] = Field(default=None, description="When tier started")
    completed_at: Optional[datetime] = Field(default=None, description="When tier completed")
    duration_seconds: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Duration in seconds")
    progress: Optional[TaskProgress] = Field(default=None, description="Progress information")
    ray_job_id: Optional[StrictStr] = Field(default=None, description="Ray job ID")
    ray_dashboard_url: Optional[StrictStr] = Field(default=None, description="Link to Ray dashboard")
    error: Optional[StrictStr] = Field(default=None, description="Error message if failed")
    error_type: Optional[StrictStr] = Field(default=None, description="Error type if failed")
    __properties: ClassVar[List[str]] = ["tier_num", "task_id", "status", "started_at", "completed_at", "duration_seconds", "progress", "ray_job_id", "ray_dashboard_url", "error", "error_type"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TierDiagnostic from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of progress
        if self.progress:
            _dict['progress'] = self.progress.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TierDiagnostic from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "tier_num": obj.get("tier_num"),
            "task_id": obj.get("task_id"),
            "status": obj.get("status"),
            "started_at": obj.get("started_at"),
            "completed_at": obj.get("completed_at"),
            "duration_seconds": obj.get("duration_seconds"),
            "progress": TaskProgress.from_dict(obj["progress"]) if obj.get("progress") is not None else None,
            "ray_job_id": obj.get("ray_job_id"),
            "ray_dashboard_url": obj.get("ray_dashboard_url"),
            "error": obj.get("error"),
            "error_type": obj.get("error_type")
        })
        return _obj





# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from mixpeek.models.attribute_based_config import AttributeBasedConfig
from mixpeek.models.cluster_stats import ClusterStats
from mixpeek.models.cluster_type import ClusterType
from mixpeek.models.llm_labeling_output import LLMLabelingOutput
from mixpeek.models.logical_operator_output import LogicalOperatorOutput
from mixpeek.models.source_enrichment_config import SourceEnrichmentConfig
from mixpeek.models.task_status_enum import TaskStatusEnum
from mixpeek.models.vector_based_config_output import VectorBasedConfigOutput
from typing import Optional, Set
from typing_extensions import Self

class ClusterModel(BaseModel):
    """
    Cluster metadata stored in MongoDB.
    """ # noqa: E501
    collection_ids: Optional[Annotated[List[StrictStr], Field(min_length=1)]] = Field(default=None, description="Collections to cluster together")
    cluster_name: Optional[StrictStr] = Field(default=None, description="Optional human-friendly name for the clustering job")
    cluster_type: Optional[ClusterType] = Field(default=None, description="Vector or attribute clustering")
    vector_config: Optional[VectorBasedConfigOutput] = Field(default=None, description="Required when cluster_type is 'vector'")
    attribute_config: Optional[AttributeBasedConfig] = Field(default=None, description="Required when cluster_type is 'attribute'")
    filters: Optional[LogicalOperatorOutput] = Field(default=None, description="Optional filters to pre-filter documents before clustering (same format as list documents). Applied during Qdrant scroll before parquet export. Useful for clustering subsets like: status='active', category='electronics', etc.")
    llm_labeling: Optional[LLMLabelingOutput] = Field(default=None, description="Optional configuration for LLM-based cluster labeling. When provided with enabled=True, clusters will have semantic labels generated by LLM instead of generic labels like 'Cluster 0'. When not provided or enabled=False, uses fallback labels.")
    enrich_source_collection: Optional[StrictBool] = Field(default=False, description="If True, cluster results are written back to source collection(s) in-place instead of creating new output collections. Documents will be enriched with cluster_id, cluster_label, distance_to_centroid, and optionally other metadata. Similar to taxonomy enrichment pattern.")
    source_enrichment_config: Optional[SourceEnrichmentConfig] = Field(default=None, description="Configuration for source collection enrichment (only used if enrich_source_collection=True). Controls which fields are added to source documents and field naming conventions.")
    cluster_id: Optional[StrictStr] = Field(default=None, description="Unique cluster identifier")
    parquet_path: Optional[StrictStr] = Field(default=None, description="S3 path to parquet files with cluster data")
    members_key: Optional[StrictStr] = Field(default=None, description="S3 key to members.parquet (if saved)")
    num_clusters: Optional[StrictInt] = Field(default=None, description="Number of clusters found")
    cluster_stats: Optional[ClusterStats] = Field(default=None, description="Clustering quality metrics")
    status: Optional[TaskStatusEnum] = Field(default=None, description="Clustering job status")
    task_id: Optional[StrictStr] = Field(default=None, description="Associated task ID for clustering job")
    last_run_id: Optional[StrictStr] = Field(default=None, description="Run ID of the most recent successful clustering execution. Used to retrieve execution results.")
    created_at: Optional[datetime] = Field(default=None, description="When the cluster was created")
    updated_at: Optional[datetime] = Field(default=None, description="When the cluster was last updated")
    metadata: Optional[Dict[str, Any]] = Field(default=None, description="Additional user-defined metadata for the cluster")
    __properties: ClassVar[List[str]] = ["collection_ids", "cluster_name", "cluster_type", "vector_config", "attribute_config", "filters", "llm_labeling", "enrich_source_collection", "source_enrichment_config", "cluster_id", "parquet_path", "members_key", "num_clusters", "cluster_stats", "status", "task_id", "last_run_id", "created_at", "updated_at", "metadata"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ClusterModel from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of vector_config
        if self.vector_config:
            _dict['vector_config'] = self.vector_config.to_dict()
        # override the default output from pydantic by calling `to_dict()` of attribute_config
        if self.attribute_config:
            _dict['attribute_config'] = self.attribute_config.to_dict()
        # override the default output from pydantic by calling `to_dict()` of filters
        if self.filters:
            _dict['filters'] = self.filters.to_dict()
        # override the default output from pydantic by calling `to_dict()` of llm_labeling
        if self.llm_labeling:
            _dict['llm_labeling'] = self.llm_labeling.to_dict()
        # override the default output from pydantic by calling `to_dict()` of source_enrichment_config
        if self.source_enrichment_config:
            _dict['source_enrichment_config'] = self.source_enrichment_config.to_dict()
        # override the default output from pydantic by calling `to_dict()` of cluster_stats
        if self.cluster_stats:
            _dict['cluster_stats'] = self.cluster_stats.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ClusterModel from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "collection_ids": obj.get("collection_ids"),
            "cluster_name": obj.get("cluster_name"),
            "cluster_type": obj.get("cluster_type"),
            "vector_config": VectorBasedConfigOutput.from_dict(obj["vector_config"]) if obj.get("vector_config") is not None else None,
            "attribute_config": AttributeBasedConfig.from_dict(obj["attribute_config"]) if obj.get("attribute_config") is not None else None,
            "filters": LogicalOperatorOutput.from_dict(obj["filters"]) if obj.get("filters") is not None else None,
            "llm_labeling": LLMLabelingOutput.from_dict(obj["llm_labeling"]) if obj.get("llm_labeling") is not None else None,
            "enrich_source_collection": obj.get("enrich_source_collection") if obj.get("enrich_source_collection") is not None else False,
            "source_enrichment_config": SourceEnrichmentConfig.from_dict(obj["source_enrichment_config"]) if obj.get("source_enrichment_config") is not None else None,
            "cluster_id": obj.get("cluster_id"),
            "parquet_path": obj.get("parquet_path"),
            "members_key": obj.get("members_key"),
            "num_clusters": obj.get("num_clusters"),
            "cluster_stats": ClusterStats.from_dict(obj["cluster_stats"]) if obj.get("cluster_stats") is not None else None,
            "status": obj.get("status"),
            "task_id": obj.get("task_id"),
            "last_run_id": obj.get("last_run_id"),
            "created_at": obj.get("created_at"),
            "updated_at": obj.get("updated_at"),
            "metadata": obj.get("metadata")
        })
        return _obj





# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.api.notifications_api import NotificationsApi


class TestNotificationsApi(unittest.TestCase):
    """NotificationsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = NotificationsApi()

    def tearDown(self) -> None:
        pass

    def test_delete_notification(self) -> None:
        """Test case for delete_notification

        Delete Notification
        """
        pass

    def test_get_funnel_state_notifications(self) -> None:
        """Test case for get_funnel_state_notifications

        Get Funnel State
        """
        pass

    def test_get_notification(self) -> None:
        """Test case for get_notification

        Get Notification
        """
        pass

    def test_get_preferences_notifications(self) -> None:
        """Test case for get_preferences_notifications

        Get Preferences
        """
        pass

    def test_get_reminder_preferences_notifications(self) -> None:
        """Test case for get_reminder_preferences_notifications

        Get Reminder Preferences
        """
        pass

    def test_get_unread_count_notifications(self) -> None:
        """Test case for get_unread_count_notifications

        Get Unread Count
        """
        pass

    def test_list_notifications(self) -> None:
        """Test case for list_notifications

        List Notifications
        """
        pass

    def test_mark_all_as_read_notifications(self) -> None:
        """Test case for mark_all_as_read_notifications

        Mark All As Read
        """
        pass

    def test_mark_as_read_notifications(self) -> None:
        """Test case for mark_as_read_notifications

        Mark As Read
        """
        pass

    def test_update_preferences_notifications(self) -> None:
        """Test case for update_preferences_notifications

        Update Preferences
        """
        pass

    def test_update_reminder_preferences_notifications(self) -> None:
        """Test case for update_reminder_preferences_notifications

        Update Reminder Preferences
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List
from typing_extensions import Annotated
from mixpeek.models.search_result_item import SearchResultItem
from typing import Optional, Set
from typing_extensions import Self

class SearchResponse(BaseModel):
    """
    Response model for resource search results.  Contains paginated search results with metadata about total matches and pagination state. Results are sorted by relevance (exact matches first, then partial matches) and creation time (newest first).  Use Cases:     - Display search results to users     - Implement pagination UI     - Show total result counts     - Navigate through large result sets  Fields:     - results: List of matched resources     - total: Total number of matches (before pagination)     - limit: Results per page (from request)     - offset: Current pagination offset (from request)
    """ # noqa: E501
    results: List[SearchResultItem] = Field(description="List of matched resources. REQUIRED. May be empty if no matches found. Sorted by: 1) Exact matches first, 2) Partial matches, 3) Created timestamp descending. Length is min(total - offset, limit). Each result contains full resource metadata for display.")
    total: Annotated[int, Field(strict=True, ge=0)] = Field(description="Total number of matches across all pages. REQUIRED. Count before pagination is applied. Use to calculate total pages: ceil(total / limit). May be 0 if no matches found. Example: total=50 with limit=20 means 3 pages of results.")
    limit: Annotated[int, Field(le=100, strict=True, ge=1)] = Field(description="Results per page (from request). REQUIRED. Echo of the limit parameter from the request. Range: 1-100.")
    offset: Annotated[int, Field(strict=True, ge=0)] = Field(description="Current pagination offset (from request). REQUIRED. Echo of the offset parameter from the request. Number of results skipped. Example: offset=20 means results start from the 21st match.")
    __properties: ClassVar[List[str]] = ["results", "total", "limit", "offset"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SearchResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in results (list)
        _items = []
        if self.results:
            for _item_results in self.results:
                if _item_results:
                    _items.append(_item_results.to_dict())
            _dict['results'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SearchResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "results": [SearchResultItem.from_dict(_item) for _item in obj["results"]] if obj.get("results") is not None else None,
            "total": obj.get("total"),
            "limit": obj.get("limit"),
            "offset": obj.get("offset")
        })
        return _obj


